@@ -91,7 +91,6 @@ OC.L10N.register(
     "Next week – {timeLocale}" : "La próxima selmana – {timeLocale}",
     "Could not delete message" : "Nun se pudo desaniciar el mensaxe",
     "Could not archive message" : "Nun se pudo archivar el mensaxe",
-    "Draft: " : "Borrador:",
     "Encrypted message" : "Mensaxe cifráu",
     "This message is unread" : "Esta mensaxe ta ensin lleer",
     "Favorite" : "Meter en Favoritos",
@@ -220,6 +219,7 @@ OC.L10N.register(
     "Save sieve settings" : "Guardar la configuración de sieve",
     "The syntax seems to be incorrect:" : "La sintaxis paez ser incorreuta",
     "Save sieve script" : "Guardar el script de sieve",
+    "Message source" : "Orixe del mensaxe",
     "An error occurred, unable to rename the tag." : "Prodúxose un error, nun ye posible renomar la bandexa de corréu.",
     "Delete tag" : "Desaniciar la etiqueta",
     "Set tag" : "Afitar la etiqueta",
@@ -227,6 +227,63 @@ OC.L10N.register(
     "Tag already exists" : "La etiqueta yá esiste",
     "Tag name cannot be empty" : "El nome de la etiqueta nun pue tar baleru",
     "An error occurred, unable to create the tag." : "Prodúxose un error, nun ye posible crear la bandexa de corréu.",
+    "Add tag" : "Amestar una etiqueta",
+    "Saving tag …" : "Guardando la etiqueta…",
+    "Task created" : "Creóse la xera",
+    "Could not create task" : "Nun se pudo crear la xera",
+    "Summarizing thread failed." : "El resume del filu falló.",
+    "Could not load your message thread" : "Nun se pudo cargar el filu de mensaxes",
+    "Loading thread" : "Cargando'l filu",
+    "Not found" : "Nun s'atopó",
+    "Go to latest message" : "Dir al últimu mensaxe",
+    "Go to newest message" : "Dir al mensaxe más nuevu",
+    "The message could not be translated" : "Nun se pudo traducir el mensaxe",
+    "Translation copied to clipboard" : "La traducción copióse al cartafueyu",
+    "Translation could not be copied" : "Nun se pudo copiar la traducción",
+    "Translate message" : "Traducir el mensaxe",
+    "Translating" : "Traduciendo",
+    "Copy translated text" : "Copiar el testu traducíu",
+    "Untitled event" : "Eventu ensin títulu",
+    "Airplane" : "Avión",
+    "Train" : "Tren",
+    "Flag" : "Bandera",
+    "Operator" : "Operador",
+    "contains" : "contién",
+    "matches" : "concasa",
+    "Filter name" : "Nome de la peñera",
+    "Priority" : "Prioridá",
+    "Error saving config" : "Hebo un error al guardar la configuración",
+    "Anti Spam Service" : "Serviciu de antispam",
+    "Gmail integration" : "Integración con Gmail",
+    "Anti Spam" : "Antispam",
+    "Reset" : "Reafitar",
+    "Client ID" : "ID de veceru",
+    "Client secret" : "Secretu de veceru",
+    "IMAP" : "IMAP",
+    "User" : "Usuariu",
+    "Host" : "Agospiador",
+    "Port" : "Puertu",
+    "SMTP" : "SMTP",
+    "Master password" : "Contraseña maestra",
+    "Use master password" : "Usar la contraseña maestra",
+    "Sieve" : "Sieve",
+    "Save Config" : "Guardar la configuración",
+    "Failed to import the certificate. Please check the password." : "Nun se pue importar el certificáu. Comprueba la contraseña.",
+    "Certificate imported successfully" : "El certificáu importóse correutamente",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Nun se pue importar el certificáu. Asegúrate de que la clave privada concasa cola del certificáu y nun ta protexida con una clave d'accesu.",
+    "Failed to import the certificate" : "Nun se pue importar el certificáu",
+    "S/MIME certificates" : "Certificaos S/MIME",
+    "Certificate name" : "Nome del certificáu",
+    "E-mail address" : "Direición de corréu electrónicu",
+    "Delete certificate" : "Desaniciar el certificáu",
+    "No certificate imported yet" : "Nun s'importó nengún certificáu",
+    "Import certificate" : "Importar el certificáu",
+    "PEM Certificate" : "Certificáu PEM",
+    "Certificate" : "Certificáu",
+    "Private key (optional)" : "Clave privada (opcional)",
+    "Submit" : "Unviar",
+    "Account connected" : "Cuenta conectada",
+    "You can close this window" : "Pues zarrar esta ventana",
     "All" : "Too",
     "Drafts" : "Borradores",
     "Favorites" : "Favoritos",
@@ -248,6 +305,8 @@ OC.L10N.register(
     "Could not load the message" : "Nun se pudo cargar el mensaxe",
     "Error loading message" : "Hebo un error al cargar el mensaxe",
     "Redirect" : "Redirixir",
-    "The link leads to %s" : "L'enllaz lleva a %s"
+    "The link leads to %s" : "L'enllaz lleva a %s",
+    "Draft: " : "Borrador:",
+    "Actions" : "Aiciones"
 },
 "nplurals=2; plural=(n != 1);");
