@@ -15,6 +15,7 @@ OC.L10N.register(
     "SMTP Password" : "SMTP Şifrəsi",
     "Signature" : "İmza",
     "Cancel" : "Dayandır",
+    "Accounts" : "Accounts",
     "General" : "Ümumi",
     "Archive" : "Arxiv",
     "Delete" : "Sil",
@@ -49,6 +50,16 @@ OC.L10N.register(
     "Close" : "Bağla",
     "Date" : "Date",
     "Tags" : "Işarələr",
+    "Not found" : "Tapılmadı",
+    "Priority" : "Prioritet",
+    "Reset" : "Sıfırla",
+    "Client ID" : "Müştəri İD-s",
+    "Client secret" : "Müxtəri sirri",
+    "User" : "User",
+    "Host" : "Şəbəkədə ünvan",
+    "Port" : "Port",
+    "Valid until" : "Vaxtadək keçərlidir",
+    "Certificate" : "Sertifikat",
     "All" : "Hamısı",
     "Drafts" : "Qaralamalar",
     "Favorites" : "Sevimlilər",
@@ -56,6 +67,7 @@ OC.L10N.register(
     "Junk" : "Önəmsiz",
     "Sent" : "Göndərildi",
     "Trash" : "Zibil",
-    "Error loading message" : "Mesajın yüklənməsində səhv baş verdi"
+    "Error loading message" : "Mesajın yüklənməsində səhv baş verdi",
+    "Actions" : "İşlər"
 },
 "nplurals=2; plural=(n != 1);");
