@@ -56,8 +56,17 @@ OC.L10N.register(
     "Close" : "Serriñ",
     "Date" : "Deiz",
     "Tags" : "Klavioù",
+    "Translate to" : "Treiñ e",
+    "Client ID" : "ID kliant",
+    "User" : "Implijer",
+    "Host" : "Ostiz",
+    "Port" : "Porzh",
+    "Valid until" : "Gwir betek",
+    "Submit" : "Kinnig",
+    "Account connected" : "Kont kenstaged",
     "All" : "Pep tra",
     "Favorites" : "Pennrolloù",
-    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr"
+    "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
+    "Actions" : "Oberoù"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
