@@ -31,6 +31,7 @@ OC.L10N.register(
     "Go back" : "Nôl",
     "Email address" : "Cyfeiriad e-bost",
     "Cancel" : "Diddymu",
+    "Accounts" : "Accounts",
     "Add mail account" : "Ychwanegu cyfrif post",
     "General" : "Cyffredinol",
     "List" : "Rhestr",
@@ -56,7 +57,6 @@ OC.L10N.register(
     "Choose" : "Dewisa",
     "Choose a file to add as attachment" : "Dewiswch ffeil i'w hychwanegu fel atodiad",
     "Confirm" : "Cadarnhau",
-    "Draft: " : "Drafft:",
     "Favorite" : "Ffefryn",
     "Back" : "Nôl",
     "Create event" : "Creu digwyddiad",
@@ -91,6 +91,13 @@ OC.L10N.register(
     "Date" : "Date",
     "Tags" : "Tagiau",
     "Custom" : "Cyfaddas",
+    "Not found" : "Heb ei ganfod",
+    "Untitled event" : "Digwyddiad di-deitl",
+    "(organizer)" : "(trefnydd)",
+    "Recipient" : "Derbynnydd",
+    "User" : "Defnyddwyr",
+    "Certificate" : "Tystysgrif",
+    "Connect your mail account" : "Cysylltu â'r cyfrif e-bost",
     "All" : "Popeth",
     "Drafts" : "Drafftiau",
     "Favorites" : "Ffefrynnau",
@@ -112,6 +119,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Cliciwch yma os na chewch eich ailgyfeirio'n awtomatig o fewn yr ychydig eiliadau nesaf.",
     "Redirect" : "Ailgyfeirio",
     "The link leads to %s" : "Mae'r ddolen yn arwain at %s",
-    "Continue to %s" : "Parhau i %s"
+    "Continue to %s" : "Parhau i %s",
+    "Draft: " : "Drafft:",
+    "Actions" : "Gweithredoedd"
 },
 "nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
