@@ -78,7 +78,6 @@ OC.L10N.register(
     "Confirm" : "Konfirmi",
     "Plain text" : "Ebenaĵa teksto",
     "Blind copy recipients only" : "Nur blindkopiaj ricevontoj",
-    "Draft: " : "Malneto:",
     "Unfavorite" : "Malpliŝatati",
     "Favorite" : "Pliŝatati",
     "Read" : "Legi",
@@ -140,6 +139,36 @@ OC.L10N.register(
     "Save signature" : "Konservi subskribon",
     "Delete tag" : "Forigi etikedon",
     "Tag already exists" : "La etikedo jam ekzistas",
+    "Not found" : "Ne trovita",
+    "Reply to sender only" : "Respondi nur al sendinto",
+    "Untitled event" : "Sentitola okazaĵo",
+    "Import into {calendar}" : "Importi en {calendar}",
+    "Event imported into {calendar}" : "Okazaĵo importis en {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flugo {flightNr} de {depAirport} al {arrAirport}",
+    "Airplane" : "Aviadilo",
+    "Reservation {id}" : "Rezervejo {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} de {depStation} al {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Trajno de {depStation} al {arrStation}",
+    "Train" : "Trajno",
+    "Recipient" : "Ricevonto",
+    "matches" : "kongruas kun",
+    "Priority" : "Prioritato",
+    "Mail app" : "Retpoŝtprogrameto",
+    "Reset" : "Restarigi",
+    "Client ID" : "Klientidentigilo",
+    "Client secret" : "Klientosekreto",
+    "Email: {email}" : "Retpoŝto: {email}",
+    "IMAP" : "IMAP",
+    "User" : "Uzanto",
+    "Host" : "Gastigo",
+    "Port" : "Pordo",
+    "SMTP" : "SMTP",
+    "E-mail address" : "Retpoŝtadreso",
+    "Valid until" : "Valida ĝis",
+    "Certificate" : "Atestilo",
+    "Submit" : "Sendi",
+    "Account connected" : "Konto konektita",
+    "Connect your mail account" : "Konekti vian retpoŝtan konton",
     "All" : "Ĉiuj",
     "Drafts" : "Malnetujo",
     "Favorites" : "Pliŝataĵoj",
@@ -161,6 +190,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Alklaku ĉi tie, ĉu vi ne estos aŭtomate alidirektita post kelkaj sekundoj.",
     "Redirect" : "Alidirekto",
     "The link leads to %s" : "La ligilo iras al %s",
-    "Continue to %s" : "Daŭrigi al %s"
+    "Continue to %s" : "Daŭrigi al %s",
+    "Draft: " : "Malneto:",
+    "Actions" : "Agoj"
 },
 "nplurals=2; plural=(n != 1);");
