@@ -180,7 +180,6 @@ OC.L10N.register(
     "No trash mailbox configured" : "No se ha configurado una bandeja de papelera",
     "Could not delete message" : "No se pudo eliminar el mensaje",
     "Could not archive message" : "No se pudo archivar el mensaje",
-    "Draft: " : "Borrador: ",
     "Encrypted message" : "Mensaje cifrado",
     "This message is unread" : "Este mensaje no se ha leído",
     "Unfavorite" : "Quitar favorito",
@@ -390,6 +389,7 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Tu firma tiene un tamaño mayor de 2 MB. Esto puede afectar el rendimiento de tu editor.",
     "Save signature" : "Guardar firma",
     "Place signature above quoted text" : "Colocar firma sobre el texto citado",
+    "Message source" : "Origen del mensaje",
     "An error occurred, unable to rename the tag." : "Ocurrió un error, no se pudo cambiar el nombre de la etiqueta.",
     "Saving new tag name …" : "Guardando nuevo nombre de etiqueta ...",
     "Set tag" : "Establecer etiqueta",
@@ -397,6 +397,165 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "El nombre de la etiqueta es una etiqueta oculta del sistema",
     "Tag already exists" : "La etiqueta ya existe",
     "An error occurred, unable to create the tag." : "Ocurrió un error, no se pudo crear la etiqueta.",
+    "Add default tags" : "Agregar etiquetas predeterminadas",
+    "Add tag" : "Agregar etiqueta",
+    "Saving tag …" : "Guardando etiqueta ...",
+    "Task created" : "Tarea creada",
+    "Could not create task" : "No se pudo crear la tarea",
+    "No calendars with task list support" : "No hay calendarios con soporte de lista de tareas",
+    "Could not load your message thread" : "No se pudo cargar el hilo de mensajes",
+    "The thread doesn't exist or has been deleted" : "El hilo no existe o ha sido eliminado",
+    "Loading thread" : "Cargando hilo",
+    "Not found" : "No encontrado",
+    "Encrypted & verified " : "Cifrado y verificado ",
+    "Signature verified" : "Firma verificada",
+    "Signature unverified " : "Firma no verificada ",
+    "This message was encrypted by the sender before it was sent." : "Este mensaje fue cifrado por el remitente antes de enviarlo.",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Este mensaje contiene una firma digital S/MIME verificada. El mensaje no ha sido modificado desde que fue enviado.",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Este mensaje contiene una firma digital S/MIME no verificada. El mensaje podría haber sido modificado desde que fue enviado o el certificado del firmante no es confiable.",
+    "Reply all" : "Responder a todos",
+    "Unsubscribe request sent" : "Solicitud de cancelación de suscripción enviada",
+    "Could not unsubscribe from mailing list" : "No se pudo cancelar la suscripción a la lista de correo",
+    "Unsubscribe" : "Cancelar suscripción",
+    "Reply to sender only" : "Responder solo al remitente",
+    "Mark as unfavorite" : "Marcar como no favorito",
+    "Mark as favorite" : "Marcar como favorito",
+    "Mark as unread" : "Marcar como no leído",
+    "Mark as read" : "Marcar como leído",
+    "Unsubscribe via link" : "Cancelar suscripción mediante enlace",
+    "Unsubscribing will stop all messages from the mailing list {sender}" : "Cancelar la suscripción detendrá todos los mensajes de la lista de correo {sender}",
+    "Send unsubscribe email" : "Enviar correo electrónico de cancelación de suscripción",
+    "Unsubscribe via email" : "Cancelar suscripción por correo electrónico",
+    "The message could not be translated" : "No se pudo traducir el mensaje",
+    "Translation copied to clipboard" : "Traducción copiada al portapapeles",
+    "Translation could not be copied" : "No se pudo copiar la traducción",
+    "Translate message" : "Traducir mensaje",
+    "Source language to translate from" : "Idioma de origen para traducir",
+    "Translate from" : "Traducir desde",
+    "Target language to translate into" : "Idioma de destino para la traducción",
+    "Translate to" : "Traducir a",
+    "Translating" : "Traduciendo",
+    "Copy translated text" : "Copiar texto traducido",
+    "Could not remove trusted sender {sender}" : "No se pudo eliminar el remitente confiable {sender}",
+    "No senders are trusted at the moment." : "No hay remitentes confiables en este momento.",
+    "Untitled event" : "Evento sin título",
+    "(organizer)" : "(organizador)",
+    "Import into {calendar}" : "Importar en {calendar}",
+    "Event imported into {calendar}" : "Evento importado en {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Vuelo {flightNr} desde {depAirport} a {arrAirport}",
+    "Airplane" : "Avión",
+    "Reservation {id}" : "Reserva {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} desde {depStation} a {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Tren desde {depStation} a {arrStation}",
+    "Train" : "Tren",
+    "Flag" : "Bandera",
+    "Recipient" : "Destinatario",
+    "Operator" : "Operador",
+    "contains" : "contiene",
+    "matches" : "coincide",
+    "Priority" : "Prioridad",
+    "Successfully updated config for \"{domain}\"" : "Configuración actualizada con éxito para \"{domain}\"",
+    "Error saving config" : "Error al guardar la configuración",
+    "Saved config for \"{domain}\"" : "Configuración guardada para \"{domain}\"",
+    "Could not save provisioning setting" : "No se pudo guardar la configuración de aprovisionamiento",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Se aprovisionó con éxito {count} cuenta.","Se aprovisionaron con éxito {count} cuentas.","Se aprovisionaron con éxito {count} cuentas."],
+    "There was an error when provisioning accounts." : "Se produjo un error al aprovisionar cuentas.",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Cuentas eliminadas y desaprovisionadas con éxito para \"{domain}\"",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Error al eliminar y desaprovisionar cuentas para \"{domain}\"",
+    "Mail app" : "Aplicación de correo",
+    "The mail app allows users to read mails on their IMAP accounts." : "La aplicación de correo permite a los usuarios leer correos en sus cuentas IMAP.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Aquí puedes encontrar la configuración a nivel de instancia. La configuración específica del usuario se encuentra en la propia aplicación (esquina inferior izquierda).",
+    "Account provisioning" : "Provisión de cuentas",
+    "A provisioning configuration will provision all accounts with a matching email address." : "Una configuración de provisión aprovisionará todas las cuentas con una dirección de correo electrónico coincidente.",
+    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "El uso del comodín (*) en el campo de dominio de provisión creará una configuración que se aplica a todos los usuarios, siempre y cuando no coincidan con otra configuración.",
+    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "El mecanismo de provisión priorizará las configuraciones de dominio específicas sobre la configuración de dominio comodín.",
+    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Si se encuentra una nueva configuración coincidente después de que el usuario ya haya sido aprovisionado con otra configuración, la nueva configuración tendrá prioridad y el usuario será aprovisionado nuevamente con la configuración.",
+    "There can only be one configuration per domain and only one wildcard domain configuration." : "Solo puede haber una configuración por dominio y solo una configuración de dominio comodín.",
+    "These settings can be used in conjunction with each other." : "Estos ajustes se pueden utilizar conjuntamente.",
+    "If you only want to provision one domain for all users, use the wildcard (*)." : "Si solo deseas aprovisionar un dominio para todos los usuarios, utiliza el comodín (*).",
+    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Esta configuración solo tiene más sentido si utilizas el mismo back-end de usuario para tu Nextcloud y servidor de correo de tu organización.",
+    "Provisioning Configurations" : "Configuraciones de provisión",
+    "Add new config" : "Agregar nueva configuración",
+    "Provision all accounts" : "Aprovisionar todas las cuentas",
+    "Allow additional mail accounts" : "Permitir cuentas de correo adicionales",
+    "Allow additional Mail accounts from User Settings" : "Permitir cuentas de correo adicionales desde la configuración del usuario",
+    "Anti Spam Service" : "Servicio Anti Spam",
+    "You can set up an anti spam service email address here." : "Aquí puedes configurar una dirección de correo electrónico para el servicio anti spam.",
+    "Any email that is marked as spam will be sent to the anti spam service." : "Cualquier correo electrónico que sea marcado como spam será enviado al servicio anti spam.",
+    "Gmail integration" : "Integración con Gmail",
+    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail permite a los usuarios acceder a su correo electrónico a través de IMAP. Por razones de seguridad, este acceso solo es posible con una conexión OAuth 2.0 o cuentas de Google que utilizan autenticación de dos factores y contraseñas de aplicaciones.",
+    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Debes registrar un nuevo ID de cliente para una \"aplicación web\" en la consola de Google Cloud. Agrega la URL {url} como URI de redirección autorizado.",
+    "Microsoft integration" : "Integración con Microsoft",
+    "Successfully set up anti spam email addresses" : "Direcciones de correo electrónico para informes de spam configuradas con éxito",
+    "Error saving anti spam email addresses" : "Error al guardar las direcciones de correo electrónico para informes de spam",
+    "Successfully deleted anti spam reporting email" : "Correo electrónico de informe de spam eliminado correctamente",
+    "Error deleting anti spam reporting email" : "Error al eliminar el correo electrónico de informe de spam",
+    "Anti Spam" : "Anti Spam",
+    "Add the email address of your anti spam report service here." : "Agrega la dirección de correo electrónico de tu servicio de informes anti spam aquí.",
+    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Cuando uses esta configuración, se enviará un correo electrónico de informe al servidor de informes SPAM cuando un usuario haga clic en \"Marcar como spam\".",
+    "The original message will be attached as a \"message/rfc822\" attachment." : "El mensaje original se adjuntará como un archivo \"message/rfc822\".",
+    "\"Mark as Spam\" Email Address" : "Dirección de correo electrónico para \"Marcar como Spam\"",
+    "\"Mark Not Junk\" Email Address" : "Dirección de correo electrónico para \"Marcar como No Deseado\"",
+    "Reset" : "Restablecer",
+    "Google integration configured" : "Integración con Google configurada",
+    "Could not configure Google integration" : "No se pudo configurar la integración con Google",
+    "Google integration unlinked" : "Integración con Google desvinculada",
+    "Could not unlink Google integration" : "No se pudo desvincular la integración con Google",
+    "Client ID" : "ID del cliente",
+    "Client secret" : "Secreto del cliente",
+    "Unlink" : "Desvincular",
+    "Microsoft integration configured" : "Integración con Microsoft configurada",
+    "Could not configure Microsoft integration" : "No se pudo configurar la integración con Microsoft",
+    "Microsoft integration unlinked" : "Integración con Microsoft desvinculada",
+    "Could not unlink Microsoft integration" : "No se pudo desvincular la integración con Microsoft",
+    "Tenant ID (optional)" : "ID de inquilino (opcional)",
+    "Domain Match: {provisioningDomain}" : "Correspondencia de dominio: {provisioningDomain}",
+    "Email: {email}" : "Correo electrónico: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} en {host}:{port} (cifrado {ssl})",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} en {host}:{port} (cifrado {ssl})",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} en {host}:{port} (cifrado {ssl})",
+    "Configuration for \"{provisioningDomain}\"" : "Configuración para \"{provisioningDomain}\"",
+    "Provisioning domain" : "Dominio de aprovisionamiento",
+    "Email address template" : "Plantilla de dirección de correo electrónico",
+    "IMAP" : "IMAP",
+    "User" : "Usuario",
+    "Host" : "Servidor",
+    "Port" : "Puerto",
+    "SMTP" : "SMTP",
+    "Sieve" : "Sieve",
+    "Enable sieve integration" : "Habilitar integración con Sieve",
+    "LDAP aliases integration" : "Integración con alias LDAP",
+    "Enable LDAP aliases integration" : "Habilitar integración con alias LDAP",
+    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "La integración con alias LDAP lee un atributo del directorio LDAP configurado para aprovisionar alias de correo electrónico.",
+    "LDAP attribute for aliases" : "Atributo LDAP para alias",
+    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Atributo multivalor para aprovisionar alias de correo electrónico. Se crea un alias para cada valor. Los alias existentes en Nextcloud que no estén en el directorio LDAP se eliminarán.",
+    "Save Config" : "Guardar configuración",
+    "Unprovision & Delete Config" : "Desaprovisionar y eliminar configuración",
+    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% y %EMAIL% se reemplazarán con el UID y el correo electrónico del usuario",
+    "With the settings above, the app will create account settings in the following way:" : "Con la configuración anterior, la aplicación creará configuraciones de cuenta de la siguiente manera:",
+    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "El certificado PKCS #12 proporcionado debe contener al menos un certificado y exactamente una clave privada.",
+    "Failed to import the certificate. Please check the password." : "Error al importar el certificado. Por favor, verifica la contraseña.",
+    "Certificate imported successfully" : "Certificado importado con éxito",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Error al importar el certificado. Por favor, asegúrate de que la clave privada coincida con el certificado y no esté protegida por una contraseña.",
+    "Failed to import the certificate" : "Error al importar el certificado",
+    "S/MIME certificates" : "Certificados S/MIME",
+    "Certificate name" : "Nombre del certificado",
+    "E-mail address" : "Dirección de correo electrónico",
+    "Valid until" : "Válido hasta",
+    "Delete certificate" : "Eliminar certificado",
+    "No certificate imported yet" : "Aún no se ha importado ningún certificado",
+    "Import certificate" : "Importar certificado",
+    "Import S/MIME certificate" : "Importar certificado S/MIME",
+    "PKCS #12 Certificate" : "Certificado PKCS #12",
+    "PEM Certificate" : "Certificado PEM",
+    "Certificate" : "Certificado",
+    "Private key (optional)" : "Clave privada (opcional)",
+    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "La clave privada solo es necesaria si tienes la intención de enviar correos electrónicos firmados y cifrados usando este certificado.",
+    "Submit" : "Enviar",
+    "Account connected" : "Cuenta conectada",
+    "You can close this window" : "Puedes cerrar esta ventana",
+    "Connect your mail account" : "Conecta tu cuenta de correo",
+    "To add a mail account, please contact your administrator." : "Para agregar una cuenta de correo, contacta a tu administrador.",
     "All" : "Todos",
     "Drafts" : "Borradores",
     "Favorites" : "Favoritos",
@@ -429,6 +588,9 @@ OC.L10N.register(
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si no deseas visitar esa página, puedes regresar a <a href=\"%s\">Correo</a>.",
-    "Continue to %s" : "Continuar a %s"
+    "Continue to %s" : "Continuar a %s",
+    "Draft: " : "Borrador: ",
+    "Actions" : "Acciones",
+    "New action" : "Nueva acción"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
