@@ -62,6 +62,7 @@ OC.L10N.register(
     "Cancel" : "Cancelar",
     "Put my text to the bottom of a reply instead of on top of it." : "Ponga mi texto al final de la respuesta en vez de encima de ella.",
     "Could not update preference" : "No se pudo actualizar la preferencia",
+    "Accounts" : "Accounts",
     "Add mail account" : "Agregar cuenta de correo",
     "General" : "General",
     "Use Gravatar and favicon avatars" : "Usar Gravatar y avatares favicon",
@@ -110,7 +111,6 @@ OC.L10N.register(
     "Rich text" : "Texto enriquecido",
     "No messages in this mailbox" : "No hay mensajes en esta bandeja",
     "No messages" : "No hay mensajes",
-    "Draft: " : "Borrador:",
     "Unfavorite" : "Desmarcar como favorito",
     "Favorite" : "Favorito",
     "Read" : "Leer",
@@ -159,6 +159,20 @@ OC.L10N.register(
     "Tags" : "Etiquetas",
     "Select tags" : "Selecciona las etiquetas",
     "Custom" : "Personalizado",
+    "Add tag" : "Agregar etiqueta",
+    "Recipient" : "Destinatario",
+    "matches" : "coincide",
+    "Priority" : "Prioridad",
+    "Reset" : "Restablecer",
+    "Client ID" : "ID del cliente",
+    "Client secret" : "Secreto del cliente",
+    "User" : "Ususario",
+    "Host" : "Servidor",
+    "Port" : "Puerto",
+    "Valid until" : "Válido hasta",
+    "Certificate" : "Certificado",
+    "Submit" : "Enviar",
+    "Connect your mail account" : "Conecta tu cuenta de correo",
     "All" : "Todos",
     "Drafts" : "Borradores",
     "Favorites" : "Favoritos",
@@ -180,6 +194,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Haz click aqui si no eres redireccionado automáticamente dentro de los siguietes segundos. ",
     "Redirect" : "Redireccionar",
     "The link leads to %s" : "La liga lleva a %s",
-    "Continue to %s" : "Continuar a %s"
+    "Continue to %s" : "Continuar a %s",
+    "Draft: " : "Borrador:",
+    "Actions" : "Acciones"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
