@@ -240,6 +240,7 @@ OC.L10N.register(
     "No messages" : "Kirju pole",
     "Blind copy recipients only" : "Vaid pimekoopia saajad",
     "No subject" : "Teemat pole",
+    "{markup-start}Draft:{markup-end} {subject}" : "{markup-start}Kavand:{markup-end} {subject}",
     "Later today – {timeLocale}" : "Täna hiljem – {timeLocale}",
     "Set reminder for later today" : "Lisa meeldetuletus tänaseks hilisemaks ajaks",
     "Tomorrow – {timeLocale}" : "Homme – {timeLocale}",
@@ -255,7 +256,6 @@ OC.L10N.register(
     "Could not snooze thread" : "Ei õnnestunud edasi lükata jutulõnga kuvamist",
     "Thread was unsnoozed" : "Jutulõnga edasilükkamine on lõpetatud",
     "Could not unsnooze thread" : "Jutulõnga edasilükkamise lõpetamine ei õnnestunud",
-    "Draft: " : "Kavand:",
     "This summary was AI generated" : "See koond on loodud tehisaru poolt",
     "Encrypted message" : "Krüptitud e-kiri",
     "This message is unread" : "See kiri on lugemata",
@@ -526,6 +526,7 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Sinu e-kirjade allkiri on suurem, kui 2 MB ja see võib mõjutada kirjutamisliidese jõudlust.",
     "Save signature" : "Salvesta allkiri",
     "Place signature above quoted text" : "Aseta allkiri tsiteeritud teksti ette",
+    "Message source" : "Kirja lähtekood",
     "An error occurred, unable to rename the tag." : "Tekkis viga ning sildi nime ei saanud muuta.",
     "Edit name or color" : "Muuda nime või värvi",
     "Saving new tag name …" : "Salvestan sildi uut nime…",
@@ -536,7 +537,186 @@ OC.L10N.register(
     "Tag already exists" : "Silt on juba olemas",
     "Tag name cannot be empty" : "Sildi nimi ei saa jääda tühjaks",
     "An error occurred, unable to create the tag." : "Tekkis viga ning silti ei saanud luua.",
+    "Add default tags" : "Lisa vaikimisi sildid",
+    "Add tag" : "Lisa silt",
+    "Saving tag …" : "Salvestan silti…",
+    "Task created" : "Ülesanne on koostatud",
+    "Could not create task" : "Ülesande koostamine ei õnnestunud",
+    "No calendars with task list support" : "Pole ülesannete toega kalendrit",
+    "Summarizing thread failed." : "Jutulõngast ei õnnestunud teha kokkuvõtet.",
+    "Could not load your message thread" : "Sinu kirjade jutulõnga ei õnnestunud alla laadida",
+    "The thread doesn't exist or has been deleted" : "Jutulõnga pole olemas või on kustutatud",
+    "Email was not able to be opened" : "E-kirja polnud võimalik avada",
     "Print" : "Prindi",
+    "Loading thread" : "Laadin jutulõnga",
+    "Not found" : "Ei leidu",
+    "Encrypted & verified " : "Krüptitud ja verifitseeritud",
+    "Signature verified" : "Allkiri on verifitseeritud",
+    "Signature unverified " : "Allkiri on verifitseerimata",
+    "This message was encrypted by the sender before it was sent." : "See kiri krüptiti enne saatmist saatja poolt.",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Sellel kirjal on verifitseeritud  S/MIME allkiri. Kirja pole pärast saatmist  muudetud.",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Sellel kirjal on verifitseerimata S/MIME allkiri. Kirja võib olla pärast saatmist muudetud või saatja sertifikaat pole usaldusväärne.",
+    "Reply all" : "Vasta kõigile",
+    "Unsubscribe request sent" : "Tellimusest loobumise päring on saadetud",
+    "Could not unsubscribe from mailing list" : "Postiloendi tellimusest loobumine ei õnnestunud",
+    "Please wait for the message to load" : "Palun oota, kuni e-kirja laadimine on lõppenud",
+    "Disable reminder" : "Lülita meeldetuletus välja",
+    "Unsubscribe" : "Lõpeta tellimus",
+    "Reply to sender only" : "Vasta vaid saatjale",
+    "Mark as unfavorite" : "Märgi mittelemmikuks",
+    "Mark as favorite" : "Märgi lemmikuks",
+    "Mark as unread" : "Märgi mitteloetuks",
+    "Mark as read" : "Märgi loetuks",
+    "Unsubscribe via link" : "Loobu tellimusest lingi kaudu",
+    "Unsubscribing will stop all messages from the mailing list {sender}" : "Tellimusest loobudes sa enam ei saa kirju postiloendist {sender}",
+    "Send unsubscribe email" : "Saada loobumiskiri",
+    "Unsubscribe via email" : "Saada tellimusest loobumine e-kirjana",
+    "{name} Assistant" : "Abiline: {name}",
+    "Go to latest message" : "Mine vanima kirja juurde",
+    "Go to newest message" : "Mine viimase kirja juurde",
+    "Thread summary" : "Jutulõnga kokkuvõte",
+    "Please select languages to translate to and from" : "Palun vali keeled, mille vahel tahad tõlkida",
+    "The message could not be translated" : "E-kirja tõlkimine ei õnnestunud",
+    "Translation copied to clipboard" : "Tõlge on kopeeritud lõikelauale",
+    "Translation could not be copied" : "Tõlke kopeerimine ei õnnestunud",
+    "Translate message" : "Tõlgi e-kiri",
+    "Source language to translate from" : "Tõlke lähtekeel",
+    "Translate from" : "Lähtekeel tõlkimisel",
+    "Target language to translate into" : "Sihtkeel tõlkimisel",
+    "Translate to" : "Tõlke sihtkeel",
+    "Translating" : "Tõlkimisel",
+    "Copy translated text" : "Kopeeri tõlgitud tekst",
+    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Prügikasti sisu säilitamise saad keelata, kui jätad välja tühjaks või märkides selle 0-ks. Töödeldakse ainult pärast prügikasti säilitamise lubamist kustutatud e-kirju.",
+    "Could not remove trusted sender {sender}" : "Usaldatud saatja eemaldamine ei õnnestunud: {sender}",
+    "No senders are trusted at the moment." : "Sa hetkel ei usalda ühtegi kirjasaatjat.",
+    "Untitled event" : "Ilma nimeta sündmus",
+    "(organizer)" : "(korraldaja)",
+    "Import into {calendar}" : "Impordi kalendrisse {calendar}",
+    "Event imported into {calendar}" : "Sündmus on imporditud kalendrisse: {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Lend {flightNr}:  {depAirport} → {arrAirport}",
+    "Airplane" : "Lennuk",
+    "Reservation {id}" : "Broneering {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "Rong {trainNr}:  {depStation} → {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Rong: {depStation} → {arrStation}",
+    "Train" : "Rong",
+    "Delete action" : "Kustuta tegevus",
+    "Flag" : "Märgi",
+    "The stop action ends all processing" : "See tegevus lõpetab kogu töötlemise",
+    "Sender" : "Saatja",
+    "Recipient" : "Saaja",
+    "Create a new mail filter" : "Koosta uus e-posti filter",
+    "Choose the headers you want to use to create your filter. In the next step, you will be able to refine the filter conditions and specify the actions to be taken on messages that match your criteria." : "Vali päisekirjed, mida tahad oma filtri loomisel kasutada. Järgmises sammus saad filtrite tingimusi täpsustada ja määratleda tegevused, mida nende täitmisel tehakse.",
+    "Delete filter" : "Kustuta filter",
+    "Delete mail filter {filterName}?" : "Kas kustutame e-posti filtri „{filterName}“?",
+    "Are you sure to delete the mail filter?" : "Kas sa oled kindel, et soovid selle e-postifiltri kustutada?",
+    "New filter" : "Uus filter",
+    "Filter saved" : "Filter on salvestatud",
+    "Could not save filter" : "Filtri salvestamine ei õnnestunud",
+    "Filter deleted" : "Filter on kustutatud",
+    "Could not delete filter" : "Filtri kustutamine on õnnestunud",
+    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Halda e-kirjade kaost. Filtrid aitavad sul olulist esile tõsta ja müra eemaldada.",
+    "Filter is active" : "Filter on kasutusel",
+    "Filter is not active" : "Filter pole kasutusel",
+    "Operator" : "Operaator",
+    "If all the conditions are met, the actions will be performed" : "Kui kõik tingimused vastavad siis, need tegevused käivitatakse",
+    "If any of the conditions are met, the actions will be performed" : "Kui mõni tingimus vastab siis, need tegevused käivitatakse",
+    "is exactly" : "on täpselt",
+    "contains" : "sisaldab",
+    "matches" : "kattub",
+    "Delete test" : "Kustuta test",
+    "Update mail filter" : "Uuenda e-posti filtrit",
+    "Filter name" : "Filtri nimi",
+    "If all the conditions are met" : "Kui kõik tingimused on täidetud",
+    "If any of the conditions are met" : "Kui mõni tingimutest on täidetud",
+    "Add condition" : "Lisa tingimus",
+    "Then perform these actions" : "Seejärel käivita need tegevused",
+    "Actions are triggered when the specified tests are true. The following actions are available:" : "Tegevused käivituvad, kui konkreetse testi vastus on tõene. Saadaval on järgnevad tegevused:",
+    "Moves the message into a specified folder." : "Teisaldab kirja etteantud kausta.",
+    "Adds a flag to the message." : "Lisab kirjale märgistuse.",
+    "Halts the execution of the filter script. No further filters with will be processed after this action." : "Lõpetab Sieve skripti töö. Peale seda ei töödelda ühtegi järgnevat tingimust.",
+    "Add action" : "Lisa tegevus",
+    "Priority" : "Olulisus",
+    "Enable filter" : "Kasuta filtrit",
+    "Save filter" : "Salvesta filter",
+    "Successfully updated config for \"{domain}\"" : "„{domain}“ domeeni seadistuste uuendamine õnnestus",
+    "Error saving config" : "Viga seadistuste salvestamisel",
+    "Saved config for \"{domain}\"" : "„{domain}“ domeeni seadistused on salvestatud",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count} kasutajakonto ettevalmistamine õnnestus","{count} kasutajakonto ettevalmistamine õnnestus"],
+    "Mail app" : "E-posti rakendus",
+    "The mail app allows users to read mails on their IMAP accounts." : "Selle rakendusega saavad kasutajad lugeda oma IMAP-i kontode kirju.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Siin on serverikohased seadistused. Kasutajakohased seadistused leiduvad rakenduses (vaata alumist vasakut nurka).",
+    "Add new config" : "Lisa uus konfiguratsioon",
+    "Allow additional mail accounts" : "Lisa veel e-postikontosid",
+    "Allow additional Mail accounts from User Settings" : "Luba kasutaja seadistustest täiendavate e-posti kontode kasutamine",
+    "Enable text processing through LLMs" : "Kasuta teksti töötlemist suure keelemudeliga",
+    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "E-postirakendus oskab töödelda kasutajaandmeid seadistatud keelemudeli abil ning selle teha abitoiminguid, nagu jutulõngade ülevaadete, nutikate vastuste ja ürituste päevakavade koostamine.",
+    "Enable LLM processing" : "Lülita suure keelemudeliga töötlemine sisse",
+    "Gmail integration" : "Lõiming Gmailiga",
+    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail lubab kasutajatel lugeda kirju IMAP-i abil. Turvakaalutlustel toimib see vaid OAuth 2.0 liidestusega või kui Google'i konto kasutab kaheastmelist autentimist ja rakenduse salasõna.",
+    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Sa pead Google Cloudi juhtpaneelis registreerima veebirakenduse (Web application) jaoks uue klienditunnuse (Client ID). Korrektse suunamisaadressina kasuta: {url}",
+    "Microsoft integration" : "Lõiming Microsofti e-postiteenusega",
+    "Microsoft requires you to access your emails via IMAP using OAuth 2.0 authentication. To do this, you need to register an app with Microsoft Entra ID, formerly known as Microsoft Azure Active Directory." : "Microsoft lubab kasutajatel lugeda kirju IMAP-i abil. Turvakaalutlustel toimib see vaid OAuth 2.0 liidestusega. Selleks palun registreeri oma rakendus teenuses Microsoft Entra ID, varasema nimega Microsoft Azure Active Directory.",
+    "Redirect URI" : "Ümbersuunamise aadress (URI)",
+    "For more details, please click here to open our documentation." : "Lisateavet leiad meie dokumentatsioonist ↗.",
+    "User Interface Preference Defaults" : "Kasutusliidese eelistuste vaikimisi väärtused",
+    "These settings are used to pre-configure the user interface preferences they can be overridden by the user in the mail settings" : "Need on kasutajaliidese eelseadistused, mida iga kasutaja saab oma seadistustest muuta",
+    "Reset" : "Lähtesta",
+    "Google integration configured" : "Google'i e-postiteenuste lõiming on seadistatud",
+    "Could not configure Google integration" : "Google'i e-postiteenuste lõimingu seadistamine ei õnnestunud",
+    "Google integration unlinked" : "Google'i e-postiteenuste lõiming on eemaldatud",
+    "Could not unlink Google integration" : "Google'i e-postiteenuste lõimingu eemaldamine ei õnnestunud",
+    "Client ID" : "Kliendi tunnus",
+    "Client secret" : "Kliendi saladus",
+    "Unlink" : "Eemalda lõiming",
+    "Microsoft integration configured" : "Microsofti e-postiteenuste lõiming on seadistatud",
+    "Could not configure Microsoft integration" : "Microsofti e-postiteenuste lõimingu seadistamine ei õnnestunud",
+    "Microsoft integration unlinked" : "Microsofti e-postiteenuste lõiming on eemaldatud",
+    "Could not unlink Microsoft integration" : "Microsofti e-postiteenuste lõimingu eemaldamine ei õnnestunud",
+    "Tenant ID (optional)" : "Üüriliskasutaja tunnus (valikuline)",
+    "Domain Match: {provisioningDomain}" : "Domeeni sobivus: {provisioningDomain}",
+    "Email: {email}" : "E-post: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} serveris {host}:{port} ({ssl} krüptimisega)",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} serveris {host}:{port} ({ssl} krüptimisega)",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} serveris {host}:{port} ({ssl} krüptimisega)",
+    "Email address template" : "E-posti aadressi mall",
+    "IMAP" : "IMAP",
+    "User" : "Kasutaja",
+    "Host" : "Host",
+    "Port" : "Port",
+    "SMTP" : "SMTP",
+    "Master password" : "Üldsalasõna",
+    "Use master password" : "Kasuta üldsalasõna",
+    "Sieve" : "Sieve",
+    "Enable sieve integration" : "Võta Sieve'i lõiming kasutusele",
+    "LDAP aliases integration" : "LDAP-i aliaste lõiming",
+    "Enable LDAP aliases integration" : "Võta kasutusele LDAP-i aliaste lõiming",
+    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP-i aliaste lõiming võimaldab lugeda andmeid määratud LDAP-teenuse serverist ja selle alusel eelkoostada e-posti aliasi.",
+    "LDAP attribute for aliases" : "LDAP-i omadused aliaste jaoks",
+    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Mitmeväärtuseline e-posti aliaste eelkoostamise lahendus. Iga väärtuse kohta luuakse alias. Nexctcloudis leiduvate aliaste puhul, millel pole LDAP-i serveris vastet, kustutakse e-posti teenusest.",
+    "Save Config" : "Salvesta seadistus",
+    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Lisatud PKCS #12 sertifikaadis peab olema vähemalt üks sertifikaat ning ainult üks privaatvõti.",
+    "Failed to import the certificate. Please check the password." : "Sertifikaadi importimine ei õnnestunud. Palun kontrolli, kas salasõna on õige.",
+    "Certificate imported successfully" : "Sertifikaadi importimine õnnestus",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Sertifikaadi importimine ei õnnestunud. Palun kontrolli, et privaatvõti vastab sertifikaadile ja ta ei ole salafraasiga krüptitud.",
+    "Failed to import the certificate" : "Sertifikaadi importimine ei õnnestunud",
+    "S/MIME certificates" : "S/MIME sertifikaadid",
+    "Certificate name" : "Sertifikaadi nimi",
+    "E-mail address" : "E-posti aadress",
+    "Valid until" : "Kehtib kuni",
+    "Delete certificate" : "Kustuta sertifikaat",
+    "No certificate imported yet" : "Ühtegi sertifikaati pole imporditud",
+    "Import certificate" : "Impordi sertifikaat",
+    "Import S/MIME certificate" : "Impordi S/MIME sertifikaat",
+    "PKCS #12 Certificate" : "PKCS #12 sertifikaat",
+    "PEM Certificate" : "PEM sertifikaat",
+    "Certificate" : "Sertifikaat",
+    "Private key (optional)" : "Privaatvõti (kui vaja)",
+    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Privaatvõtit on vaja vaid siis, kui plaanid selle sertifikaadiga saata allkirjastatud ja krüptitud e-kirju.",
+    "Submit" : "Saada",
+    "Account connected" : "Konto ühendatud",
+    "You can close this window" : "Võid selle akna sulgeda.",
+    "Connect your mail account" : "Ühenda oma e-posti kontoga",
+    "To add a mail account, please contact your administrator." : "Oma e-posti konto lisamiseks palun võta ühendust oma peakasutajaga.",
     "All" : "Kõik",
     "Drafts" : "Mustandid",
     "Favorites" : "Lemmikud",
@@ -573,6 +753,13 @@ OC.L10N.register(
     "Redirect" : "Suunamine",
     "The link leads to %s" : "Link viitab siia: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Kui sa ei taha seda lehte avada, siis mine tagasi <a href=\"%s\">E-postirakenduse</a> lehele.",
-    "Continue to %s" : "Jätka siia: %s"
+    "Continue to %s" : "Jätka siia: %s",
+    "Draft: " : "Kavand:",
+    "If all tests pass, then the actions will be executed" : "Kui kõik testid toimivad, siis tegevused käivitatakse",
+    "If one test pass, then the actions will be executed" : "Kui üks test toimib, siis tegevused käivitatakse",
+    "Tests" : "Testid",
+    "New test" : "Uus test",
+    "Actions" : "Tegevused",
+    "New action" : "Uus tegevus"
 },
 "nplurals=2; plural=(n != 1);");
