@@ -179,7 +179,6 @@ OC.L10N.register(
     "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
     "Could not delete message" : "Ei voitu poistaa viestiä",
     "Could not archive message" : "Viestiä ei voitu arkistoida",
-    "Draft: " : "Luonnos: ",
     "Encrypted message" : "Salattu viesti",
     "This message is unread" : "Tämä viesti on lukematon",
     "Unfavorite" : "Poista suosikeista",
@@ -360,12 +359,112 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Allekirjoituksesi koko on yli kaksi megatavua. Tämä saattaa vaikuttaa muokkaimen suorituskykyyn.",
     "Save signature" : "Tallenna allekirjoitus",
     "Place signature above quoted text" : "Aseta allekirjoitus lainatun tekstin yläpuolelle",
+    "Message source" : "Viestin lähde",
     "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
     "Saving new tag name …" : "Tallennetaan uuden tunnisteen nimeä…",
     "Delete tag" : "Poista tunniste",
     "Tag name is a hidden system tag" : "Tunnisteen nimi on piilotettu järjestelmätunniste",
     "Tag already exists" : "Tunniste on jo olemassa",
     "An error occurred, unable to create the tag." : "Tapahtui virhe, tunnistetta ei voitu luoda.",
+    "Add default tags" : "Lisää oletustunnisteet",
+    "Add tag" : "Lisää tunniste",
+    "Saving tag …" : "Tallennetaan tunnistetta…",
+    "Task created" : "Tehtävä luotu",
+    "Could not load your message thread" : "Viestiketjua ei voitu ladata",
+    "The thread doesn't exist or has been deleted" : "Ketjua ei ole olemassa tai se on poistettu",
+    "Loading thread" : "Ladataan ketjua",
+    "Not found" : "Ei löytynyt",
+    "Encrypted & verified " : "Salattu ja vahvistettu",
+    "Signature verified" : "Allekirjoitus vahvistettu",
+    "Signature unverified " : "Allekirjoitus vahvistamatta",
+    "This message was encrypted by the sender before it was sent." : "Tämän viestin lähettäjä salasi viestin ennen sen lähettämistä.",
+    "Reply all" : "Vastaa kaikille",
+    "Unsubscribe" : "Peruuta tilaus",
+    "Reply to sender only" : "Vastaa vain lähettäjälle",
+    "Mark as favorite" : "Merkitse suosikiksi",
+    "Mark as unread" : "Merkitse lukemattomaksi",
+    "Mark as read" : "Merkitse luetuksi",
+    "The message could not be translated" : "Viestiä ei voitu kääntää",
+    "Translation copied to clipboard" : "Käännös kopioitu leikepöydälle",
+    "Translation could not be copied" : "Käännöstä ei voitu kopioida",
+    "Translate message" : "Käännä viesti",
+    "Source language to translate from" : "Lähdekieli, josta käännetään",
+    "Translate from" : "Lähdekieli",
+    "Target language to translate into" : "Kohdekieli, jolle käännetään",
+    "Translate to" : "Kohdekieli",
+    "Translating" : "Käännetään",
+    "Copy translated text" : "Kopioi käännetty teksti",
+    "Could not remove trusted sender {sender}" : "Ei voitu poistaa luotettua lähettäjää {sender}",
+    "No senders are trusted at the moment." : "Ei luotettuja lähettäjiä tällä hetkellä.",
+    "Untitled event" : "Nimetön tapahtuma",
+    "(organizer)" : "(järjestäjä)",
+    "Import into {calendar}" : "Tuo kalenteriin {calendar}",
+    "Event imported into {calendar}" : "Tapahtuma tuotiin kalenteriin {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Lento {flightNr} lentokentältä {depAirport} lentokentälle {arrAirport}",
+    "Airplane" : "Lentokone",
+    "Reservation {id}" : "Varaus {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} asemalta {depStation} asemalle {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Juna asemalta {depStation} asemalle {arrStation}",
+    "Train" : "Juna",
+    "Flag" : "Lippu",
+    "Recipient" : "Vastaanottaja",
+    "Delete filter" : "Poista suodatin",
+    "Operator" : "Operaattori",
+    "contains" : "sisältää",
+    "matches" : "täsmää",
+    "Filter name" : "Nimisuodatin",
+    "Priority" : "Tärkeys",
+    "Mail app" : "Sähköpostisovellus",
+    "The mail app allows users to read mails on their IMAP accounts." : "Tämä sähköpostisovellus mahdollistaa käyttäjien lukea sähköpostiviestejä IMAP-tileiltä.",
+    "Account provisioning" : "Käyttäjän provisiointi",
+    "Provisioning Configurations" : "Provisiointi-asetukset",
+    "Add new config" : "Lisää uusi asetus",
+    "Provision all accounts" : "Provisioidaan kaikki käyttäjät",
+    "Anti Spam Service" : "Roskapostin estopalvelu",
+    "Gmail integration" : "Gmail-integraatio",
+    "Microsoft integration" : "Microsoft-integraatio",
+    "Anti Spam" : "Roskapostin esto",
+    "The original message will be attached as a \"message/rfc822\" attachment." : "Alkuperäinen viesti asetetaan \"message/rfc822\"-liitteeksi.",
+    "Reset" : "Palauta",
+    "Google integration configured" : "Google-integraatio määritetty",
+    "Could not configure Google integration" : "Google-integraatiota ei voitu määrittää",
+    "Google integration unlinked" : "Google-integraation linkitys poistettu",
+    "Client ID" : "Asiakas-ID",
+    "Client secret" : "Asiakassalasana",
+    "Unlink" : "Poista linkitys",
+    "Microsoft integration configured" : "Microsoft-integraatio määritetty",
+    "Could not configure Microsoft integration" : "Microsoft-integraatiota ei voitu määrittää",
+    "Email: {email}" : "Sähköposti: {email}",
+    "IMAP" : "IMAP",
+    "User" : "Käyttäjä",
+    "Host" : "Palvelin",
+    "Port" : "Portti",
+    "SMTP" : "SMTP",
+    "Sieve" : "Sieve",
+    "LDAP aliases integration" : "LDAP-aliasten integraatio",
+    "Enable LDAP aliases integration" : "Käytä LDAP-aliasten integraatiota",
+    "Save Config" : "Tallenna asetus",
+    "With the settings above, the app will create account settings in the following way:" : "Sovellus luo tiliasetukset yllä olevin asetuksin seuraavasti:",
+    "Certificate imported successfully" : "Varmenne tuotu onnistuneesti",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Varmenteen tuonti epäonnistui. Varmista, että yksityinen avain vastaa varmennetta ja ettei se ole suojattu tunnuslauseella.",
+    "Failed to import the certificate" : "Varmenteen tuominen epäonnistui",
+    "S/MIME certificates" : "S/MIME-varmenteet",
+    "Certificate name" : "Varmenteen nimi",
+    "E-mail address" : "Sähköpostiosoite",
+    "Valid until" : "Kelvollinen",
+    "Delete certificate" : "Poista varmenne",
+    "No certificate imported yet" : "Varmennetta ei ole vielä tuotu",
+    "Import certificate" : "Tuo varmenne",
+    "Import S/MIME certificate" : "Tuo S/MIME-varmenne",
+    "PKCS #12 Certificate" : "PKCS #12 -varmenne",
+    "PEM Certificate" : "PEM-varmenne",
+    "Certificate" : "Varmenne",
+    "Private key (optional)" : "Yksityinen avain (valinnainen)",
+    "Submit" : "Lähetä",
+    "Account connected" : "Tili yhdistetty",
+    "You can close this window" : "Voit sulkea tämän ikkunan",
+    "Connect your mail account" : "Yhdistä sähköpostitilisi",
+    "To add a mail account, please contact your administrator." : "Ole yhteydessä ylläpitoon lisätäksesi sähköpostitilin.",
     "All" : "Kaikki",
     "Drafts" : "Luonnokset",
     "Favorites" : "Suosikit",
@@ -396,6 +495,9 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klikkaa jos sinua ei uudelleenohjata automaattisesti muutamaan sekuntiin.",
     "Redirect" : "Uudelleenohjaus",
     "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
-    "Continue to %s" : "Jatka sivulle %s"
+    "Continue to %s" : "Jatka sivulle %s",
+    "Draft: " : "Luonnos: ",
+    "Actions" : "Toiminnot",
+    "New action" : "Uusi toiminto"
 },
 "nplurals=2; plural=(n != 1);");
