@@ -114,7 +114,6 @@ OC.L10N.register(
     "Blind copy recipients only" : "Samo primatelji skrivenih kopija poruke",
     "No trash mailbox configured" : "Nije konfiguriran sandučić za izbrisanu poštu",
     "Could not delete message" : "Brisanje poruke nije uspjelo",
-    "Draft: " : "Skica: ",
     "Unfavorite" : "Ukloni iz favorita",
     "Favorite" : "Favorit",
     "Read" : "Čitaj",
@@ -255,11 +254,105 @@ OC.L10N.register(
     "Signature …" : "Potpis...",
     "Save signature" : "Spremi potpis",
     "Place signature above quoted text" : "Stavi potpis iznad citiranog teksta",
+    "Message source" : "Izvor poruke",
     "An error occurred, unable to rename the tag." : "Došlo je do pogreške, nije moguće promijeniti naziv oznake.",
     "Saving new tag name …" : "Spremanje novog naziva oznake…",
     "Delete tag" : "Izbriši oznaku",
     "Tag already exists" : "Oznaka već postoji",
     "An error occurred, unable to create the tag." : "Došlo je do pogreške, nije moguće stvoriti oznaku.",
+    "Add default tags" : "Dodaj zadane oznake",
+    "Add tag" : "Dodaj oznaku",
+    "Saving tag …" : "Spremanje oznake...",
+    "Could not load your message thread" : "Učitavanje vaše dretve poruka nije uspjelo",
+    "Not found" : "Nije pronađeno",
+    "Unsubscribe" : "Otkaži pretplatu",
+    "Reply to sender only" : "Odgovori pošiljatelju",
+    "Mark as unread" : "Označi kao nepročitano",
+    "Mark as read" : "Označi kao pročitano",
+    "Could not remove trusted sender {sender}" : "Nije moguće ukloniti pouzdanog pošiljatelja {sender}",
+    "No senders are trusted at the moment." : "Trenutno nema pouzdanih pošiljatelja.",
+    "Untitled event" : "Događaj bez naslova",
+    "(organizer)" : "(organizator)",
+    "Import into {calendar}" : "Uvezi u {calendar}",
+    "Event imported into {calendar}" : "Događaj je uvezen u {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Let {flightNr} iz {depAirport} do {arrAirport}",
+    "Airplane" : "Zrakoplov",
+    "Reservation {id}" : "Rezervacija {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} do {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} do {arrStation}",
+    "Train" : "Vlak",
+    "Recipient" : "Primatelj",
+    "matches" : "podudara se",
+    "Priority" : "Prioritet",
+    "Successfully updated config for \"{domain}\"" : "Konfiguracija za „{domain}“ je uspješno ažurirana",
+    "Error saving config" : "Pogreška pri spremanju konfiguracije",
+    "Saved config for \"{domain}\"" : "Konfiguracija za „{domain}“ je spremljena",
+    "Could not save provisioning setting" : "Spremanje postavke dodjeljivanja nije uspjelo",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Dodjeljivanje je uspješno izvedeno za {count} račun.","Dodjeljivanje je uspješno izvedeno za {count} računa.","Dodjeljivanje je uspješno izvedeno za {count} računa."],
+    "There was an error when provisioning accounts." : "Došlo je do pogreške pri dodjeljivanju računa.",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Računima za „{domain}“ je ukinuto dodjeljivanje i izbrisani su",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Pogreška pri brisanju i ukidanju dodjele računa za „{domain}“",
+    "Mail app" : "Aplikacija za upravljanje e-poštom",
+    "The mail app allows users to read mails on their IMAP accounts." : "Aplikacija za upravljanje e-poštom omogućuje korisnicima da čitaju svoje poruke s IMAP računa.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Ovdje možete pronaći postavke za čitavu instancu. Postavke za pojedinog korisnika nalaze se u samoj aplikaciji (donji lijevi kut).",
+    "Account provisioning" : "Uspostavljanje računa",
+    "A provisioning configuration will provision all accounts with a matching email address." : "Konfiguracija dodjeljivanja omogućit će sve račune s odgovarajućom adresom e-pošte.",
+    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Korištenje zamjenskog znaka (*) u polju domene dodjeljivanja stvorit će konfiguraciju koja se primjenjuje na sve korisnike pod uvjetom da se ne podudaraju s drugom konfiguracijom.",
+    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Mehanizam dodjeljivanja daje prednost konfiguracijama određene domene nad konfiguracijom zamjenske domene.",
+    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Ako se pronađe nova podudarna konfiguracija nakon što je korisniku već dodijeljena druga konfiguracija, nova će konfiguracija imati prednost i korisniku će se ponovno dodijeliti konfiguracija.",
+    "There can only be one configuration per domain and only one wildcard domain configuration." : "Domena može imati samo jednu konfiguraciju i može postojati samo jedna zamjenska konfiguracija domene.",
+    "These settings can be used in conjunction with each other." : "Ove se postavke mogu upotrebljavati u kombinaciji.",
+    "If you only want to provision one domain for all users, use the wildcard (*)." : "Ako želite dodijeliti samo jednu domenu za sve korisnike, upotrijebite zamjenski znak (*).",
+    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Ova postavka ima smisla samo ako upotrebljavate isti korisnički pozadinski sustav za svoj Nextcloud i poslužitelj e-pošte organizacije.",
+    "Provisioning Configurations" : "Konfiguracije uspostavljanja",
+    "Add new config" : "Dodaj novu konfiguraciju",
+    "Provision all accounts" : "Dodijeli sve račune",
+    "Anti Spam Service" : "Usluga za sprječavanje neželjene pošte",
+    "You can set up an anti spam service email address here." : "Ovdje možete postaviti adresu e-pošte za uslugu sprječavanja neželjene pošte.",
+    "Any email that is marked as spam will be sent to the anti spam service." : "Svaka poruka e-pošte koja je označena kao neželjena pošta šalje se usluzi za sprječavanje neželjene pošte.",
+    "Successfully set up anti spam email addresses" : "Uspješno postavljene adrese e-pošte za sprječavanje neželjene pošte",
+    "Error saving anti spam email addresses" : "Pogreška pri spremanju adresa e-pošte za sprječavanje neželjene pošte",
+    "Successfully deleted anti spam reporting email" : "Uspješno izbrisana adresa e-pošte za prijavu neželjene pošte",
+    "Error deleting anti spam reporting email" : "Pogreška pri brisanju adrese e-pošte za prijavu neželjene pošte",
+    "Anti Spam" : "Sprječavanje neželjene pošte",
+    "Add the email address of your anti spam report service here." : "Ovdje dodajte adresu e-pošte svoje usluge za prijavljivanje neželjene pošte.",
+    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Kada upotrebljavate ovu postavku, poruka e-pošte s prijavom šalje se poslužitelju za prijavu neželjene pošte kada korisnik klikne na „Označi kao neželjenu poštu”.",
+    "The original message will be attached as a \"message/rfc822\" attachment." : "Izvorna poruka bit će priložena kao privitak „message/rfc822”.",
+    "\"Mark as Spam\" Email Address" : "Adresa e-pošte „Označi kao neželjenu poštu”",
+    "\"Mark Not Junk\" Email Address" : "Adresa e-pošte „Označi da nije neželjena pošta”",
+    "Reset" : "Resetiraj",
+    "Client ID" : "ID klijenta",
+    "Client secret" : "Tajni ključ klijenta",
+    "Domain Match: {provisioningDomain}" : "Podudaranje domene: {provisioningDomain}",
+    "Email: {email}" : "E-pošta: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} na {host}:{port} ({ssl} šifriranje)",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} na {host}:{port} ({ssl} šifriranje)",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} na {host}:{port} ({ssl} šifriranje)",
+    "Configuration for \"{provisioningDomain}\"" : "Konfiguracija za „{provisioningDomain}“",
+    "Provisioning domain" : "Dodjeljivanje domene",
+    "Email address template" : "Predložak adrese e-pošte",
+    "IMAP" : "IMAP",
+    "User" : "@string/user_icon",
+    "Host" : "Glavno računalo",
+    "Port" : "Port",
+    "SMTP" : "SMTP",
+    "Sieve" : "Sieve",
+    "Enable sieve integration" : "Omogućite Sieve integraciju",
+    "LDAP aliases integration" : "Integracija pseudonima za LDAP",
+    "Enable LDAP aliases integration" : "Omogući integraciju pseudonima za LDAP",
+    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "Integracija pseudonima za LDAP čita atribut iz konfiguriranog LDAP direktorija radi dodjeljivanja pseudonima e-pošte.",
+    "LDAP attribute for aliases" : "LDAP atribut za pseudonime",
+    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Viševrijednosni atribut za dodjeljivanje pseudonima e-pošte. Za svaku se vrijednost stvara pseudonim. Brišu se pseudonimi koji postoje u Nextcloudu, ali koji nisu u LDAP direktoriju.",
+    "Save Config" : "Spremi konfiguraciju",
+    "Unprovision & Delete Config" : "Ukini dodjelu i izbriši konfiguraciju",
+    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% i %EMAIL% bit će zamijenjeni korisničkim UID-om i e-poštom",
+    "With the settings above, the app will create account settings in the following way:" : "Aplikacija će primijeniti navedene postavke i stvoriti račun na sljedeći način:",
+    "E-mail address" : "Adresa e-pošte",
+    "Valid until" : "Vrijedi do",
+    "Certificate" : "Vjerodajnica",
+    "Submit" : "Šalji",
+    "Account connected" : "Račun povezan",
+    "Connect your mail account" : "Poveži svoj račun e-pošte",
     "All" : "Sve",
     "Drafts" : "Skice",
     "Favorites" : "Favoriti",
@@ -285,6 +378,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Kliknite ovdje ako niste preusmjereni automatski unutar sljedećih nekoliko sekundi.",
     "Redirect" : "Preusmjeri",
     "The link leads to %s" : "Ova poveznica vodi do %s",
-    "Continue to %s" : "Idi do %s"
+    "Continue to %s" : "Idi do %s",
+    "Draft: " : "Skica: ",
+    "Actions" : "Radnje"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
