@@ -204,7 +204,6 @@ OC.L10N.register(
     "Could not snooze thread" : "Nem lehet felfügegszteni a szálat/folyamatot",
     "Thread was unsnoozed" : "Folyatódott a szál/folyamat ",
     "Could not unsnooze thread" : "Nem lehet folytatni a szálat/folyamatot ",
-    "Draft: " : "Piszkozat: ",
     "Encrypted message" : "Titkosított üzenet",
     "This message is unread" : "Ez az üzenet olvasatlan",
     "Unfavorite" : "Nem kedvenc",
@@ -435,6 +434,7 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Az aláírás 2 MB-nál nagyobb. Ez hatással lehet a szerkesztő teljesítményére",
     "Save signature" : "Aláírás mentése",
     "Place signature above quoted text" : "Az aláírás az idézett szöveg fölé helyezése",
+    "Message source" : "Üzenet forrása",
     "An error occurred, unable to rename the tag." : "Hiba történt, a címke nem nevezhető át",
     "Edit name or color" : "Név vagy szín szerkesztése",
     "Saving new tag name …" : "Új címkenév mentése…",
@@ -444,6 +444,173 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "A címkenév egy rejtett rendszercímke",
     "Tag already exists" : "A címke már létezik",
     "An error occurred, unable to create the tag." : "HIba történt, a címke nem hozható létre.",
+    "Add default tags" : "Alapértelmezett címkék hozzáadása",
+    "Add tag" : "Címke hozzáadása",
+    "Saving tag …" : "Címke mentése…",
+    "Task created" : "Feladat létrehozva",
+    "Could not create task" : "Nem sikerült létrehozni a feladatot",
+    "No calendars with task list support" : "Nincs feladatlista támogatással rendelkező naptár",
+    "Could not load your message thread" : "Nem sikerült betölteni az üzenetszálat",
+    "The thread doesn't exist or has been deleted" : "Ez a szál nem létezik vagy törölve lett",
+    "Loading thread" : "Szál betöltése",
+    "Not found" : "Nem található",
+    "Encrypted & verified " : "Titkosított és ellenőrzött",
+    "Signature verified" : "Az aláírás ellenőrizve",
+    "Signature unverified " : "Az aláírás nincs ellenőrizve",
+    "This message was encrypted by the sender before it was sent." : "Ezt az üzenetet az elküldése előtt titkosította a feladó.",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Az üzenet ellenőrzött S/MIME digitális aláírást tartalmaz. Az üzenet nem változott, mert már el lett küldve.",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Az üzenet nem ellenőrzött S/MIME digitális aláírást tartalmaz. Az üzenetet megváltoztathatták, mert az aláíró tanúsítványa nem megbízható",
+    "Reply all" : "Válasz mindenkinek",
+    "Unsubscribe request sent" : "Leiratkozási kérés elküldve",
+    "Could not unsubscribe from mailing list" : "Nem sikerült a leiratkozás a levelezőlistáról",
+    "Unsubscribe" : "Leiratkozás",
+    "Reply to sender only" : "Válasz csak a feladónak",
+    "Mark as unfavorite" : "Megjelölés nem kedvencként",
+    "Mark as favorite" : "Megjelölés kedvencként",
+    "Mark as unread" : "Megjelölés olvasatlanként",
+    "Mark as read" : "Megjelölés olvasottként",
+    "Unsubscribe via link" : "Leiratkozás hivatkozással",
+    "Unsubscribing will stop all messages from the mailing list {sender}" : "A leiratkozás leállít minden üzenetet, amely a(z) {sender} levelezőlistáról érkezik",
+    "Send unsubscribe email" : "Leiratkozási e-mail küldése",
+    "Unsubscribe via email" : "Leiratkozás e-mailben",
+    "{name} Assistant" : "{name} Asszisztens",
+    "Go to latest message" : "Ugrás a legrégebbi üzenethez",
+    "Go to newest message" : "Ugrás a legújabb üzenethez",
+    "The message could not be translated" : "Az üzenetet nem sikerült lefordítani",
+    "Translation copied to clipboard" : "A fordítás a vágólapra másolva",
+    "Translation could not be copied" : "A fordítást nem lehetett másolni",
+    "Translate message" : "Üzenet lefordítása",
+    "Source language to translate from" : "Fordítás forrásnyelve",
+    "Translate from" : "Fordítás a következőről:",
+    "Target language to translate into" : "Fordítás célnyelve",
+    "Translate to" : "Fordítás a következőre:",
+    "Translating" : "Fordítás ",
+    "Copy translated text" : "Lefordított szöveg másolása",
+    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Tiltsa le a lomtár megőrzését úgy, hogy üresen hagyja a mezőt, vagy állítsa 0-ra. Csak azokat a leveleket dolgozza fel a rendszer, amelyeket a kukák megőrzésének engedélyezése után töröltek.",
+    "Could not remove trusted sender {sender}" : "Nem sikerült eltávolítani a megbízható küldőt: {sender}",
+    "No senders are trusted at the moment." : "Jelenleg egyetlen küldő sem megbízható.",
+    "Untitled event" : "Névtelen esemény",
+    "(organizer)" : "(szervező)",
+    "Import into {calendar}" : "Betöltés ide: {calendar}",
+    "Event imported into {calendar}" : "Esemény importálva ide: {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{FlightNr} járat {depAirport} és {arrAirport} között",
+    "Airplane" : "Repülő",
+    "Reservation {id}" : "Foglalás {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} vonat {depStation} és {arrStation} között",
+    "Train from {depStation} to {arrStation}" : "Vonat {depStation} és {arrStation} között",
+    "Train" : "Vonat",
+    "Flag" : "Zászló",
+    "Recipient" : "Címzett",
+    "Delete filter" : "Szűrő törlése",
+    "Operator" : "Állapot",
+    "contains" : "tartalmazza",
+    "matches" : "egyezik",
+    "Filter name" : "Név szűrése",
+    "Priority" : "Prioritás",
+    "Successfully updated config for \"{domain}\"" : "A(z) „{domain}” konfigurációja sikeresen frissítve",
+    "Error saving config" : "Hiba a konfiguráció mentése során",
+    "Saved config for \"{domain}\"" : "Konfiguráció mentése ehhez: „{domain}”",
+    "Could not save provisioning setting" : "A felügyeleti beállítás nem menthető",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count} fiók felügyelete sikeresen beállítva.","{count} fiók felügyelete sikeresen beállítva."],
+    "There was an error when provisioning accounts." : "Hiba történt a fiókok felügyeletének beállítása során.",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Sikeresen törölve, és a(z) „{domain}” fiókjainak felügyelete megszüntetve",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Hiba történt a törlés és a(z) „{domain}” fiókjainak felügyeletének megszüntetése során",
+    "Mail app" : "Levelező alkalmazás",
+    "The mail app allows users to read mails on their IMAP accounts." : "A levelezőalkalmazás lehetővé teszi a felhasználók számára, hogy az IMAP-fiókokon olvassák a leveleket.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Itt találhatók a példányszintű beállítások. A felhasználóspecifikus beállításokat magában az alkalmazásban találja (a bal alsó sarokban).",
+    "Account provisioning" : "Fiókfelügyelet",
+    "A provisioning configuration will provision all accounts with a matching email address." : "A felügyeleti konfiguráció beállítja az összes olyan fiókot, amelyhez megfelelő e-mail-cím tartozik.",
+    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "A dzsóker (*) használata a felügyeleti tartománynál olyan konfigurációt hoz létre, amely minden olyan felhasználóra vonatkozik, melyek nem felelnek meg más konfigurációnak.",
+    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "A felügyeleti mechanizmus előnyben részesíti a konkrét tartományra vonatkozó konfigurációkat a dzsóker tartománykonfigurációval szemben.",
+    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Ha egy új megfelelő konfiguráció található, de a felhasználó már egy másik konfigurációval lett ellátva, akkor az új konfigurációé lesz az elsőbbség, és a felhasználó azzal lesz ellátva.",
+    "There can only be one configuration per domain and only one wildcard domain configuration." : "Tartományonként csak egy konfiguráció lehet, és dzsóker tartománykonfigurációból is csak egy lehet",
+    "These settings can be used in conjunction with each other." : "Ezek a beállítások együtt is használhatók.",
+    "If you only want to provision one domain for all users, use the wildcard (*)." : "Ha csak egy domaint akar létrehozni az összes felhasználónak, akkor használja a dzsókert (*).",
+    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Ennek a beállításnak akkor van a legtöbb értelme, ha ugyanazt a háttérrendszert használja a Nextcloudhoz és a szervezete levelezőkiszolgálójához.",
+    "Provisioning Configurations" : "Felügyeleti konfigurációk",
+    "Add new config" : "Új konfiguráció hozzáadása",
+    "Provision all accounts" : "Összes fiók felügyelete",
+    "Allow additional mail accounts" : "További postafiókok engedélyezése",
+    "Allow additional Mail accounts from User Settings" : "További levelezőfiókok hozzáadásának engedélyezése a Felhasználói beállításokból",
+    "Anti Spam Service" : "Levélszemét elleni szolgáltatás",
+    "You can set up an anti spam service email address here." : "Itt állíthatja be a levélszemét elleni szolgáltatás e-mail-címét.",
+    "Any email that is marked as spam will be sent to the anti spam service." : "Minden levélszemétnek jelölt levél el lesz küldve a levélszemét elleni szolgáltatásnak.",
+    "Gmail integration" : "Gmail-integráció",
+    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "A Gmail lehetővé teszi, hogy a felhasználók IMAP-on keresztül érjék el az e-mailjeiket. Biztonsági okokból ez csak OAuth 2.0-s kapcsolattal lehetséges, vagy olyan Google-fiókkal, amely kétfaktoros hitelesítést és alkalmazásjelszavakat használ.",
+    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Regisztrálnia kell egy új kliensazonosítót egy webalkalmazáshoz a Google Cloud konzolon. Adja meg a {url} webcímet engedélyezett átirányítási címként.",
+    "Microsoft integration" : "Microsoft integráció",
+    "Successfully set up anti spam email addresses" : "Sikeresen beállította a levélszemét elhárítási e-mail-címeket",
+    "Error saving anti spam email addresses" : "Hiba történt a levélszemét elhárítási e-mail-címek mentése során",
+    "Successfully deleted anti spam reporting email" : "Levélszemét bejelentési e-mail-cím sikeresen törölve",
+    "Error deleting anti spam reporting email" : "Hiba történt a levélszemét bejelentési e-mail-cím törlése során",
+    "Anti Spam" : "Levélszemét elhárítás",
+    "Add the email address of your anti spam report service here." : "Itt adja hozzá a levélszemét bejelentési szolgáltatása e-mail-címét.",
+    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Ha ezt a beállítást használja, akkor egy jelentési levél lesz küldve a levélszemét bejelentési kiszolgálónak, ha egy felhasználó a „Megjelölés levélszemétként” gombra kattint.",
+    "The original message will be attached as a \"message/rfc822\" attachment." : "Az eredeti üzenet „message/rfc822” mellékletként lesz csatolva.",
+    "\"Mark as Spam\" Email Address" : "„Megjelölés levélszemétként” e-mail-címe",
+    "\"Mark Not Junk\" Email Address" : "„Megjelölés nem levélszemétként” e-mail-címe",
+    "Reset" : "Alaphelyzetbe állítás",
+    "Google integration configured" : "A Google-integráció beállítva",
+    "Could not configure Google integration" : "Nem sikerült a Google-integráció beállítása",
+    "Google integration unlinked" : "Google-integráció bontva",
+    "Could not unlink Google integration" : "Nem sikerült a Google-integráció bontása",
+    "Client ID" : "Kliensazonosító",
+    "Client secret" : "Klienstitok",
+    "Unlink" : "Kapcsolat bontása",
+    "Microsoft integration configured" : "Microsoft integráció beállítva",
+    "Could not configure Microsoft integration" : "Nem sikerült a Microsoft integráció beállítása",
+    "Microsoft integration unlinked" : "Microsoft integráció szétkapcsolva",
+    "Could not unlink Microsoft integration" : "Nem sikerült a Microsoft integráció szétkapcsolása",
+    "Tenant ID (optional)" : "Bérlőazonosító (nem kötelező)",
+    "Domain Match: {provisioningDomain}" : "Megfelelő tartomány: {provisioningDomain}",
+    "Email: {email}" : "E-mail: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} itt {host}:{port} ({ssl} encryption)",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} itt {host}:{port} ({ssl} encryption)",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Levélszűrő: {user} a {host} gazdagépen: {port} ({ssl} titkosítás)",
+    "Configuration for \"{provisioningDomain}\"" : "A(z) „{provisioningDomain}” beállítása",
+    "Provisioning domain" : "Felügyeleti tartomány",
+    "Email address template" : "E-mail-címsablon",
+    "IMAP" : "IMAP",
+    "User" : "Felhasználó",
+    "Host" : "Kiszolgáló",
+    "Port" : "Port",
+    "SMTP" : "SMTP",
+    "Master password" : "Mesterjelszó",
+    "Use master password" : "Mesterjelszó használata",
+    "Sieve" : "Levélszűrő",
+    "Enable sieve integration" : "Levélszűrő integráció engedélyezése",
+    "LDAP aliases integration" : "LDAP álnevek integrációja",
+    "Enable LDAP aliases integration" : "LDAP álnevek integrációjának engedélyezése",
+    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "Az LDAP álnevek integrációja kiolvas egy attribútumot a beállított LDAP-címtárból az e-mail-címek álneveinek beállításához",
+    "LDAP attribute for aliases" : "Az álnevek LDAP attribútuma",
+    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Egy többértékű attribútum az e-mail-cím álneveinek beállításhoz. Az összes értékhez létrejön egy álnév. A Nextcloudban létező, de az LDAP címtárban nem szereplő álnevek törlésre kerülnek.",
+    "Save Config" : "Konfiguráció mentése",
+    "Unprovision & Delete Config" : "Felügyelet megszüntetése és konfiguráció törlése",
+    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* a %USERID% és az %EMAIL% le lesz cserélve a felhasználó UID-jára és az e-mail-címére",
+    "With the settings above, the app will create account settings in the following way:" : "A fenti beállításokkal az alkalmazás a következő módon hozza létre a fiókbeállításokat:",
+    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "A megadott PKCS #12 tanúsítványnak legalább egy tanúsítványt és pontosan egy titkos kulcsot kell tartalmaznia.",
+    "Failed to import the certificate. Please check the password." : "A tanúsítvány importálása nem sikerült. Ellenőrizze a jelszót.",
+    "Certificate imported successfully" : "Tanúsítvány sikeresen importálva",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "A tanúsítvány importálása sikertelen. Győződjön meg arról, hogy a privát kulcs megfelel a tanúsítványnak, és nem védi jelszó.",
+    "Failed to import the certificate" : "A tanúsítvány importálása sikertelen",
+    "S/MIME certificates" : "S/MIME tanúsítványok",
+    "Certificate name" : "Tanúsítvány neve",
+    "E-mail address" : "E-mail-cím",
+    "Valid until" : "Érvényes",
+    "Delete certificate" : "Tanúsítvány törlése",
+    "No certificate imported yet" : "Még nincs tanúsítvány importálva",
+    "Import certificate" : "Tanúsítvány importálása",
+    "Import S/MIME certificate" : "S/MIME tanúsítvány importálása",
+    "PKCS #12 Certificate" : "PKCS #12 tanúsítvány",
+    "PEM Certificate" : "PEM-tanúsítvány",
+    "Certificate" : "Tanúsítvány",
+    "Private key (optional)" : "Titkos kulcs (nem kötelező)",
+    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "A titkos kulcs csak akkor szükséges, ha aláírt és titkosított e-maileket akar küldeni a tanúsítvány használatával.",
+    "Submit" : "Beküldés",
+    "Account connected" : "Fiók csatlakoztatva",
+    "You can close this window" : "Bezárhatja ezt az ablakot",
+    "Connect your mail account" : "Kapcsolódás az e-mail-fiókjához",
+    "To add a mail account, please contact your administrator." : "Levelezőfiók hozzáadásához lépjen kapcsolatba a rendszergazdával.",
     "All" : "Összes",
     "Drafts" : "Piszkozatok",
     "Favorites" : "Kedvencek",
@@ -477,6 +644,9 @@ OC.L10N.register(
     "Redirect" : "Átirányítás",
     "The link leads to %s" : "A hivatkozás ide mutat: %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Ha nem akarja megnyitni azt az oldalt, akkor térjen vissza a <a href=\"%s\">Levelezéshez</a>.",
-    "Continue to %s" : "Folytatás ide: %s"
+    "Continue to %s" : "Folytatás ide: %s",
+    "Draft: " : "Piszkozat: ",
+    "Actions" : "Műveletek",
+    "New action" : "Új művelet"
 },
 "nplurals=2; plural=(n != 1);");
