@@ -21,6 +21,7 @@ OC.L10N.register(
     "Go back" : "Kembali",
     "Email address" : "Alamat surel",
     "Cancel" : "Membatalkan",
+    "Accounts" : "Accounts",
     "Add mail account" : "Tambahkan akun surel",
     "General" : "Umum",
     "List" : "Daftar",
@@ -72,12 +73,34 @@ OC.L10N.register(
     "Message" : "Pesan",
     "Copy to clipboard" : "Salin ke papan klip",
     "Add" : "Masukkan",
+    "Show less" : "Lihat sedikit",
     "Clear" : "Bersihkan",
     "Close" : "Tutup",
     "Date" : "Date",
     "Tags" : "Tag",
     "Custom" : "Ubahan",
     "Tag already exists" : "Tag sudah ada",
+    "Add tag" : "Tambahkan tag",
+    "Unsubscribe" : "Berhenti berlangganan",
+    "Mark as unread" : "Tandai belum dibaca",
+    "Mark as read" : "tandai sudah dibaca",
+    "Untitled event" : "Acara tanpa judul",
+    "(organizer)" : "(penyelenggara)",
+    "Recipient" : "Penerima",
+    "Operator" : "Operator",
+    "contains" : "mengandung",
+    "matches" : "cocok dengan",
+    "Allow additional Mail accounts from User Settings" : "Perbolehkan akun Mail tambahan dari Setelan Pengguna",
+    "Reset" : "Setel ulang",
+    "Client ID" : "ID Klien",
+    "Client secret" : "Rahasia klien",
+    "User" : "Pengguna",
+    "Host" : "Host",
+    "Port" : "Port",
+    "Valid until" : "Berlaku sampai",
+    "Certificate" : "Sertifikat",
+    "Account connected" : "Akun terhubung",
+    "Connect your mail account" : "Hubungkan akun surel Anda",
     "All" : "Semua",
     "Drafts" : "Konsep",
     "Favorites" : "Disukai",
@@ -91,6 +114,7 @@ OC.L10N.register(
     "Error loading message" : "Terjadi kesalahan saat memuat pesan",
     "Forwarding to %s" : "Teruskan ke %s",
     "Redirect" : "Mengalihkan",
-    "Continue to %s" : "Lanjutkan ke %s"
+    "Continue to %s" : "Lanjutkan ke %s",
+    "Actions" : "Tindakan"
 },
 "nplurals=1; plural=0;");
