@@ -182,7 +182,6 @@ OC.L10N.register(
     "No trash mailbox configured" : "Nessuna casella del cestino configurata",
     "Could not delete message" : "Impossibile eliminare il messaggio",
     "Could not archive message" : "Impossibile archiviare il messaggio",
-    "Draft: " : "Bozza:",
     "Encrypted message" : "Messaggio cifrato",
     "This message is unread" : "Questo messaggio è non letto",
     "Unfavorite" : "Rimuovi preferito",
@@ -379,12 +378,150 @@ OC.L10N.register(
     "Signature …" : "Firma...",
     "Save signature" : "Salva firma",
     "Place signature above quoted text" : "Posiziona la firma sopra il testo citato",
+    "Message source" : "Sorgente del messaggio",
     "An error occurred, unable to rename the tag." : "Si è verificato un errore, impossibile rinominare l'etichetta.",
     "Edit name or color" : "Modifica nome o colore",
     "Saving new tag name …" : "Salvataggio nuovo nome della etichetta...",
     "Delete tag" : "Elimina etichetta",
     "Tag already exists" : "L'etichetta esiste già",
     "An error occurred, unable to create the tag." : "Si è verificato un errore, impossibile creare l'etichetta.",
+    "Add default tags" : "Aggiungi etichette predefiniti",
+    "Add tag" : "Aggiungi etichetta",
+    "Saving tag …" : "Salvataggio etichetta …",
+    "Task created" : "Attività creata",
+    "Could not create task" : "Impossibile creare l'attività",
+    "Could not load your message thread" : "Impossibile caricare la tua discussione",
+    "Not found" : "Non trovato",
+    "Encrypted & verified " : "Cifrato e verificato",
+    "Signature verified" : "Firma verificata",
+    "Signature unverified " : "Firma non verificata",
+    "This message was encrypted by the sender before it was sent." : "Questo messaggio è stato cifrato dal mittente prima di essere inviato.",
+    "Reply all" : "Rispondi a tutti",
+    "Unsubscribe" : "Rimuovi sottoscrizione",
+    "Reply to sender only" : "Rispondi solo al mittente",
+    "Mark as unread" : "Segna come non letto",
+    "Mark as read" : "Segna come letto",
+    "Go to latest message" : "Vai all'ultimo messaggio",
+    "Go to newest message" : "Vai al messaggio più recente",
+    "Translate from" : "Traduci da",
+    "Translate to" : "Traduci in",
+    "Could not remove trusted sender {sender}" : "Impossibile rimuovere il mittente fidato {sender}",
+    "No senders are trusted at the moment." : "Nessun mittente è fidato al momento.",
+    "Untitled event" : "Evento senza titolo",
+    "(organizer)" : "(organizzatore)",
+    "Import into {calendar}" : "Importa in {calendar}",
+    "Event imported into {calendar}" : "Evento importato in {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Volo {flightNr} da {depAirport} a {arrAirport}",
+    "Airplane" : "Aereo",
+    "Reservation {id}" : "Prenotazione {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} da {depStation} a {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Treno da {depStation} a {arrStation}",
+    "Train" : "Treno",
+    "Flag" : "Bandiera",
+    "Recipient" : "Destinatario",
+    "Operator" : "Operatore",
+    "contains" : "contiene",
+    "matches" : "corrisponde",
+    "Priority" : "Priorità",
+    "Successfully updated config for \"{domain}\"" : "Configurazione aggiornata con successo per \"{domain}\"",
+    "Error saving config" : "Errore durante il salvataggio della configurazione",
+    "Saved config for \"{domain}\"" : "Configurazione salvata per \"{domain}\"",
+    "Could not save provisioning setting" : "Impossibile salvare l'impostazione di approvvigionamento",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Approvvigionamento di {count} account completato con successo.","Approvvigionamento di {count} account completato con successo.","Approvvigionamento di {count} account completato con successo."],
+    "There was an error when provisioning accounts." : "Si è verificato un errore durante il approvvigionamento degli account.",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : " Account eliminati e approvvigionato correttamente per \"{domain}\"",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Errore durante l'eliminazione e il approvvigionamento degli account per \"{domain}\"",
+    "Mail app" : "Applicazione di posta",
+    "The mail app allows users to read mails on their IMAP accounts." : "L'applicazione di posta consente agli utenti di leggere i messaggi dei propri account IMAP.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Qui puoi trovare le impostazioni a livello di istanza. Le impostazioni specifiche dell'utente si trovano nell'applicazione stessa (angolo in basso a sinistra).",
+    "Account provisioning" : "Account approvvigionato.",
+    "A provisioning configuration will provision all accounts with a matching email address." : "Una configurazione predisposta preparerà tutti gli account con un indirizzo email corrispondente.",
+    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Usando il metacarattere (*) nel campo del dominio di predisposizione, si creerà una configurazione che si applica a tutti gli utenti, a patto che non dipendano da un'altra configurazione.",
+    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Il meccanismo di approvvigionamento darà la priorità alle configurazioni di dominio specifiche rispetto alla configurazione di dominio con caratteri jolly.",
+    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Se viene trovata una nuova configurazione corrispondente dopo che all'utente è già stato eseguito il approvvigionamento con un'altra configurazione, la nuova configurazione avrà la precedenza e all'utente verrà effettuato nuovamente il approvvigionamento con la configurazione.",
+    "There can only be one configuration per domain and only one wildcard domain configuration." : "Può esistere una sola configurazione per dominio e una sola configurazione di dominio con caratteri jolly.",
+    "These settings can be used in conjunction with each other." : "Queste impostazioni possono essere utilizzate con altri.",
+    "If you only want to provision one domain for all users, use the wildcard (*)." : "Se desideri eseguire il approvvigionamento di un solo dominio per tutti gli utenti, utilizza il carattere jolly (*).",
+    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Questa impostazione ha più senso se utilizzi lo stesso back-end utente per la Nextcloud e il server di posta della tua organizzazione.",
+    "Provisioning Configurations" : "Configurazione di approvvigionamento",
+    "Add new config" : "Aggiungi nuova configurazione",
+    "Provision all accounts" : "Predisponi tutti gli account",
+    "Anti Spam Service" : "Servizio anti-spam",
+    "You can set up an anti spam service email address here." : "È possibile impostare un indirizzo e-mail del servizio Anti-Spam qui.",
+    "Any email that is marked as spam will be sent to the anti spam service." : "Qualsiasi email contrassegnata come posta indesiderata verrà inviata al servizio anti-spam.",
+    "Gmail integration" : "Integrazione Gmail",
+    "Microsoft integration" : "Integrazione Microsoft",
+    "Successfully set up anti spam email addresses" : "Impostare correttamente gli indirizzi e-mail anti-spam",
+    "Error saving anti spam email addresses" : "Errore durante il salvataggio degli indirizzi email anti-spam",
+    "Successfully deleted anti spam reporting email" : "Email di segnalazione anti-spam eliminata con successo",
+    "Error deleting anti spam reporting email" : "Errore durante l'eliminazione dell'email di segnalazione anti-spam",
+    "Anti Spam" : "Anti-spam",
+    "Add the email address of your anti spam report service here." : "Aggiungi qui l'indirizzo email del tuo servizio di segnalazione anti-spam.",
+    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Quando si utilizza questa impostazione, viene inviata un'e-mail di rapporto al server di rapporto SPAM quando un utente fa clic su \"Segna come posta indesiderata\".",
+    "The original message will be attached as a \"message/rfc822\" attachment." : "Il messaggio originale verrà allegato come tipo \"message/rfc822\".",
+    "\"Mark as Spam\" Email Address" : "\"Segna come spam\" l'indirizzo e-mail",
+    "\"Mark Not Junk\" Email Address" : "\"Segna come posta indesiderata\" l'indirizzo e-mail",
+    "Reset" : "Ripristina",
+    "Google integration configured" : "Integrazione di Google configurata",
+    "Could not configure Google integration" : "Impossibile configurare l'integrazione con Google",
+    "Google integration unlinked" : "Integrazione Google scollegata",
+    "Could not unlink Google integration" : "Impossibile scollegare l'integrazione Google.",
+    "Client ID" : "ID client",
+    "Client secret" : "Segreto del client",
+    "Unlink" : "Scollega",
+    "Microsoft integration configured" : "Integrazione Microsoft configurata",
+    "Could not configure Microsoft integration" : "Impossibile configurare l'integrazione di Microsoft",
+    "Microsoft integration unlinked" : "Integrazione Microsoft scollegata",
+    "Could not unlink Microsoft integration" : "Impossibile scollegare l'integrazione Microsoft",
+    "Tenant ID (optional)" : "ID tenant (facoltativo)",
+    "Domain Match: {provisioningDomain}" : "Corrispondenza di dominio: {provisioningDomain}",
+    "Email: {email}" : "Email: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} su {host}:{port} (cifratura {ssl})",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} su {host}:{port} (cifratura {ssl})",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} su {host}:{port} ({ssl} encryption)",
+    "Configuration for \"{provisioningDomain}\"" : "Configurazione per \"{provisioningDomain}\"",
+    "Provisioning domain" : "Approvvigionamento dominio",
+    "Email address template" : "Modello d'indirizzo email",
+    "IMAP" : "IMAP",
+    "User" : "Utente",
+    "Host" : "Host",
+    "Port" : "Porta",
+    "SMTP" : "SMTP",
+    "Master password" : "Password principale",
+    "Use master password" : "Usa password principale",
+    "Sieve" : "Sieve",
+    "Enable sieve integration" : "Abilita l'integrazione Sieve",
+    "LDAP aliases integration" : "Integrazione degli alias LDAP",
+    "Enable LDAP aliases integration" : "Abilita l'integrazione degli alias LDAP",
+    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "L'integrazione degli alias LDAP legge un attributo dalla directory LDAP configurata per eseguire il approvvigionamento degli e-mail alias.",
+    "LDAP attribute for aliases" : "Attributo LDAP per gli alias",
+    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Un attributo multi valore per il approvvigionamento di e-mail alias. Per ogni valore viene creato un alias. Gli alias esistenti in Nextcloud che non si trovano nella directory LDAP vengono eliminati.",
+    "Save Config" : "Salva configurazione",
+    "Unprovision & Delete Config" : "Annullare il approvvigionamento ed eliminare la configurazione",
+    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% e %EMAIL% verranno sostituiti con l'UID e l'e-mail dell'utente",
+    "With the settings above, the app will create account settings in the following way:" : "Con le impostazioni precedenti, l'applicazione creerà le impostazioni dell'account nel modo seguente:",
+    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Il certificato PKCS #12 fornito deve contenere almeno un certificato ed esattamente una chiave privata.",
+    "Failed to import the certificate. Please check the password." : "Impossibile importare il certificato. Controlla la password.",
+    "Certificate imported successfully" : "Certificato importato correttamente",
+    "Failed to import the certificate" : "Importare del certificato non riuscita",
+    "S/MIME certificates" : "Certificati S/MIME",
+    "Certificate name" : "Nome del certificato",
+    "E-mail address" : "Indirizzo di posta",
+    "Valid until" : "Valido fino al",
+    "Delete certificate" : "Elimina certificato",
+    "No certificate imported yet" : "Ancora nessun certificato importato",
+    "Import certificate" : "Importa certificato",
+    "Import S/MIME certificate" : "Importa certificato S/MIME",
+    "PKCS #12 Certificate" : "Certificato PKCS #12",
+    "PEM Certificate" : "Certificato PEM",
+    "Certificate" : "Certificato",
+    "Private key (optional)" : "Chiave privata (facoltativa)",
+    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "La chiave privata è necessaria solo se si intende inviare email firmate e cifrate utilizzando questo certificato.",
+    "Submit" : "Invia",
+    "Account connected" : "Account connesso",
+    "You can close this window" : "Puoi chiudere questa finestra",
+    "Connect your mail account" : "Connetti il tuo account di posta",
+    "To add a mail account, please contact your administrator." : "Per aggiungere un account di posta, contatta il tuo amministratore.",
     "All" : "Tutti",
     "Drafts" : "Bozze",
     "Favorites" : "Preferiti",
@@ -416,6 +553,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Fai clic qui se non viene rediretto automaticamente entro pochi secondi.",
     "Redirect" : "Redirigi",
     "The link leads to %s" : "Il collegamento conduce a %s",
-    "Continue to %s" : "Continua su %s"
+    "Continue to %s" : "Continua su %s",
+    "Draft: " : "Bozza:",
+    "Actions" : "Azioni"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
