@@ -96,6 +96,22 @@ OC.L10N.register(
     "Tags" : "ტეგები",
     "Select tags" : "აირჩიეთ ტეგები",
     "Custom" : "ინდივიდუალური",
+    "Add tag" : "ტეგის დამატება",
+    "Mark as unread" : "წაუკითხავად მონიშვნა",
+    "Mark as read" : "წაკითხულად მონიშვნა",
+    "Recipient" : "მიმღები",
+    "matches" : "ემთხვევა",
+    "Priority" : "პრიორიტეტი",
+    "Reset" : "საწყის მდოგმარეობაში დაბრუნება",
+    "Client ID" : "კლიენტის ID",
+    "Client secret" : "კლიენტის საიდუმლო",
+    "User" : "მომხმარებელი",
+    "Host" : "ჰოსტი",
+    "Port" : "პორტი",
+    "Valid until" : "ვარგისია",
+    "Certificate" : "სერტიფიკატი",
+    "Submit" : "გაგზავნა",
+    "Connect your mail account" : "დააკავშირეთ თქვენი ელ-ფოსტის ანგარიში",
     "All" : "ყველა",
     "Drafts" : "მონახაზები",
     "Favorites" : "რჩეულები",
@@ -118,6 +134,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "იმ შემთხვევაში, თუ რამდენიმე წამის განმავლობაში არ მოხდება ავტომატური გადამისამართება დააწკაპუნეთ აქ.",
     "Redirect" : "გადამისამართება",
     "The link leads to %s" : "ბმულს მიყევხართ %s-ისკენ",
-    "Continue to %s" : "%s-ისკენ გაგრძელება"
+    "Continue to %s" : "%s-ისკენ გაგრძელება",
+    "Actions" : "მოქმედებები"
 },
 "nplurals=2; plural=(n!=1);");
