@@ -11,6 +11,7 @@ OC.L10N.register(
     "Password" : "ពាក្យសម្ងាត់",
     "None" : "គ្មាន",
     "Cancel" : "បោះបង់",
+    "Accounts" : "Accounts",
     "General" : "ទូទៅ",
     "Delete" : "លុប",
     "Search" : "Search",
@@ -30,6 +31,10 @@ OC.L10N.register(
     "Close" : "បិទ",
     "Date" : "កាលបរិច្ឆេទ",
     "Tags" : "ស្លាក",
+    "contains" : "មានផ្ទុក",
+    "User" : "User",
+    "Host" : "ម៉ាស៊ីន​ផ្ទុក",
+    "Port" : "ច្រក",
     "All" : "ទាំងអស់",
     "Drafts" : "ពង្រាង",
     "Favorites" : "Favorites",
