@@ -209,7 +209,6 @@ OC.L10N.register(
     "Could not snooze thread" : "쓰레드를 다시 알림 설정할 수 없음",
     "Thread was unsnoozed" : "쓰레드의 다시 알림 설정을 해제함",
     "Could not unsnooze thread" : "쓰레드의 다시 알림 설정을 해제할 수 없음",
-    "Draft: " : "초안:",
     "Encrypted message" : "암호화된 메시지",
     "This message is unread" : "읽지 않은 메시지입니다",
     "Unfavorite" : "즐겨찾기에서 삭제",
@@ -435,6 +434,7 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "서명이 2 MB를 초과합니다. 편집기의 성능에 영향을 미칠 수 있습니다.",
     "Save signature" : "서명 저장",
     "Place signature above quoted text" : "인용 문구 상단에 서명 삽입",
+    "Message source" : "메시지 원본",
     "An error occurred, unable to rename the tag." : "오류가 발생하여 태그 이름을 변경할 수 없습니다",
     "Edit name or color" : "이름 또는 색깔 편집",
     "Saving new tag name …" : "새 태그명 저장 ...",
@@ -445,6 +445,171 @@ OC.L10N.register(
     "Tag already exists" : "태그가 이미 존재합니다.",
     "Tag name cannot be empty" : "태그 이름을 비울 수 없음",
     "An error occurred, unable to create the tag." : "오류가 발생하여 태그 이름을 생성할 수 없습니다",
+    "Add default tags" : "기본 태그 추가",
+    "Add tag" : "태그 추가",
+    "Saving tag …" : "태그 저장하는 중 ...",
+    "Task created" : "작업이 생성됨",
+    "Could not create task" : "작업을 만들 수 없음",
+    "No calendars with task list support" : "작업 목록을 지원하는 달력 없음",
+    "Summarizing thread failed." : "쓰레드 요약 실패",
+    "Could not load your message thread" : "메시지 쓰레드를 불러올 수 없음",
+    "The thread doesn't exist or has been deleted" : "쓰레드가 존재하지 않거나 삭제되었습니다",
+    "Loading thread" : "쓰레드 불러오는 중",
+    "Not found" : "찾을 수 없음",
+    "Encrypted & verified " : "암호화 및 확인됨",
+    "Signature verified" : "서명 확인됨",
+    "Signature unverified " : "서명이 확인되지 않음",
+    "This message was encrypted by the sender before it was sent." : "발신자가 발신 전 이 메시지를 암호화했습니다",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "이 메시지는 확인된 디지털 S/MIME 서명을 포함하고 있습니다. 발신된 시점으로부터 변경된 내용이 없습니다.",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "이 메시지는 확인되지 않은 디지털 S/MIME 서명을 포함하고 있습니다. 발신된 시점 이후 변경된 내용이 존재하거나 해당 서명자의 인증서가 신뢰할 수 없는 상태입니다.",
+    "Reply all" : "모두에게 답장",
+    "Unsubscribe request sent" : "구독 해지 요청을 보냄",
+    "Could not unsubscribe from mailing list" : "메일링 리스트의 구독을 해지할 수 없음",
+    "Unsubscribe" : "구독 취소",
+    "Reply to sender only" : "발신자에게만 답장",
+    "Mark as unfavorite" : "즐겨찾기에서 해제",
+    "Mark as favorite" : "즐겨찾기로 표시",
+    "Mark as unread" : "읽지 않은 것으로 표시",
+    "Mark as read" : "읽은 것으로 표시",
+    "Unsubscribe via link" : "링크로 구독 해지",
+    "Unsubscribing will stop all messages from the mailing list {sender}" : "구독 해지는 메일링 리스트 {sender}이(가) 보내는 모든 메시지의 발신을 정지합니다",
+    "Send unsubscribe email" : "구독 해지 이메일 보내기",
+    "Unsubscribe via email" : "이메일로 구독 해지",
+    "Go to latest message" : "최근 메시지로 가기",
+    "Go to newest message" : "최근 메시지로 가기",
+    "The message could not be translated" : "메시지를 번역할 수 없습니다.",
+    "Translation copied to clipboard" : "번역을 클립보드로 복사함",
+    "Translation could not be copied" : "번역을 복사할 수 없습니다.",
+    "Translate message" : "메시지 번역",
+    "Source language to translate from" : "번역될 원본의 언어",
+    "Translate from" : "다음을 번역",
+    "Target language to translate into" : "번역할 목표 언어",
+    "Translate to" : "다음으로 번역",
+    "Translating" : "번역 중",
+    "Copy translated text" : "번역한 텍스트 복사",
+    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "입력 필드를 비우거나 0으로 지정하여 휴지통 보관을 비활성화하십시오. 휴지통 보관 활성화 이후 삭제된 메일만 휴지통에서 처리됩니다.",
+    "Could not remove trusted sender {sender}" : "신뢰하는 발신자 {sender}을(를) 삭제할 수 없음",
+    "No senders are trusted at the moment." : "현재 신뢰하는 발신자가 없습니다.",
+    "Untitled event" : "제목 없는 일정",
+    "(organizer)" : "(주최자)",
+    "Import into {calendar}" : "{calendar}(으)로 가져오기",
+    "Event imported into {calendar}" : "일정을 {calendar}에 불러옴",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{depAirport}에서 {arrAirport}(으)로 향하는 {flightNr}번 항공편",
+    "Airplane" : "여객기",
+    "Reservation {id}" : "예약 {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{depStation}에서 {arrStation}(으)로 향하는 {trainNr}번 열차",
+    "Train from {depStation} to {arrStation}" : "{depStation}에서 {arrStation}(으)로 향하는 열차",
+    "Train" : "기차",
+    "Flag" : "깃발",
+    "Recipient" : "받는 사람",
+    "Delete filter" : "필터 삭제",
+    "Operator" : "운영자",
+    "contains" : "다음을 포함함",
+    "matches" : "일치함",
+    "Filter name" : "필터 이름",
+    "Priority" : "우선 순위",
+    "Successfully updated config for \"{domain}\"" : "\"{domail}\"에 대한 설정을 성공적으로 갱신함",
+    "Error saving config" : "설정을 저장하는 중 오류 발생",
+    "Saved config for \"{domain}\"" : "\"{domail}\"에 대한 설정을 저장함",
+    "Could not save provisioning setting" : "프로비전 설정을 저장할 수 없음",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["{count}개의 계정을 성공적으로 프로비전 함"],
+    "There was an error when provisioning accounts." : "계정 프로비전 중 오류 발생",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "\"{domain}\"에 해당하는 계정을 성공적으로 삭제, 프로비전 해제함",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "\"{domain}\"에 해당하는 계정을 삭제, 프로비전 해제하는 중 오류 발생",
+    "Mail app" : "Mail 앱",
+    "The mail app allows users to read mails on their IMAP accounts." : "Mail 앱은 사용자가 자신의 IMAP 계정에서 이메일을 읽을 수 있도록 합니다.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "이곳에서 인스턴스 전체에 적용되는 설정을 확인할 수 있습니다. 특정 사용자를 대상으로 하는 설정은 앱 자체에서 확인할 수 있습니다. (좌하단 구석)",
+    "Account provisioning" : "계정 프로비전",
+    "A provisioning configuration will provision all accounts with a matching email address." : "프로비전 설정은 일치하는 이메일 주소로 모든 계정을 프로비전할 것입니다.",
+    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "프로비전 도메인 필드에 와일드카드(*)를 입력할 경우 별도의 설정이 지정되지 않은 모든 사용자에게 새로운 설정을 생성하여 적용합니다.",
+    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "프로비전은 지정된 도메인 설정을 우선 처리하고 와일드카드 도메인 설정을 그 다음에 처리합니다.",
+    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "새로운 설정이 이미 다른 설정으로 프로비전된 사용자에게서 발견될 경우, 새로운 설정이 우선 적용됩니다.",
+    "There can only be one configuration per domain and only one wildcard domain configuration." : "한 도메인에 대해 하나의 와일드 카드 설정만 존재할 수 있습니다.",
+    "If you only want to provision one domain for all users, use the wildcard (*)." : "모든 사용자에 대해 프로비전을 하고자 할 경우, 와일드카드(*)를 사용하십시오.",
+    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "이 설정은 조직의 Nextcloud와 메일 서버가 같은 사용자 백엔드를 사용할 경우에만 효력이 있습니다.",
+    "Provisioning Configurations" : "프로비전 설정",
+    "Add new config" : "새 설정 추가",
+    "Provision all accounts" : "모든 계정 프로비전",
+    "Allow additional mail accounts" : "추가 이메일 계정 허용",
+    "Allow additional Mail accounts from User Settings" : "사용자 설정에서 추가 이메일 계정 설정을 허용",
+    "Anti Spam Service" : "스팸 차단 서비스",
+    "You can set up an anti spam service email address here." : "이곳에서 스팸 차단 서비스 이메일 주소를 설정할 수 있습니다.",
+    "Any email that is marked as spam will be sent to the anti spam service." : "스팸으로 표시된 모든 이메일은 스팸 차단 서비스로 전송됩니다.",
+    "Gmail integration" : "Gmail 통합",
+    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "사용자는 IMAP을 통해 Gmail에 접근할 수 있습니다. 단, 보안을 위해 OAuth 2.0 연결 또는 2단계 인증과 앱 압호를 사용하는 Google 계정만 허용합니다.",
+    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Google Cloud 콘솔의 \"웹 애플리케이션\"에서 새 클라이언트 ID를 등록할 수 있습니다. URL {url}을(를) 인증된 리다이렉트 URI로 추가하십시오",
+    "Microsoft integration" : "Microsoft 통합",
+    "Successfully set up anti spam email addresses" : "스팸 차단 이메일 주소를 성공적으로 설정함",
+    "Error saving anti spam email addresses" : "스팸 차단 이메일 주소를 저장하는 중 오류 발생",
+    "Successfully deleted anti spam reporting email" : "스팸 차단 보고 이메일을 성공적으로 삭제함",
+    "Error deleting anti spam reporting email" : "스팸 차단 보고 이메일을 삭제하는 중 오류 발생",
+    "Anti Spam" : "스팸 차단",
+    "Add the email address of your anti spam report service here." : "사용할 스팸 차단 서비스의 이메일 주소를 이곳에서 추가하십시오.",
+    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "이 설정을 사용하면, 사용자가 \"스팸으로 표시\"를 클릭할 때 신고 이메일이 SPAM 보고 서버로 전송됩니다.",
+    "The original message will be attached as a \"message/rfc822\" attachment." : "원본 메시지는 \"message/rfc822\"로 첨부됩니다.",
+    "\"Mark as Spam\" Email Address" : "\"스팸으로 표시\" 이메일 주소",
+    "\"Mark Not Junk\" Email Address" : "\"스팸 메일 아님\" 이메일 주소",
+    "Reset" : "초기화",
+    "Google integration configured" : "Google 통합이 설정됨",
+    "Could not configure Google integration" : "Google 통합을 설정할 수 없음",
+    "Google integration unlinked" : "Google 통합이 해제됨",
+    "Could not unlink Google integration" : "Google 통합을 해제할 수 없음",
+    "Client ID" : "클라이언트 ID",
+    "Client secret" : "클라이언트 비밀 값",
+    "Unlink" : "해제",
+    "Microsoft integration configured" : "Microsoft 통합이 설정됨",
+    "Could not configure Microsoft integration" : "Microsoft 통합을 설정할 수 없음",
+    "Microsoft integration unlinked" : "Microsoft 통합이 해제됨",
+    "Could not unlink Microsoft integration" : "Microsoft 통합을 해제할 수 없음",
+    "Domain Match: {provisioningDomain}" : "도메인 일치: {provisioningDomail}",
+    "Email: {email}" : "이메일: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {host}:{port} ({ssl} 암호화)의 사용자 {user}",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {host}:{port} ({ssl} 암호화)의 사용자 {user}",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {host}:{port} ({ssl} 암호화)의 사용자 {user}",
+    "Configuration for \"{provisioningDomain}\"" : "\"{provisioningDomain}\" 설정",
+    "Provisioning domain" : "도메인 프로비전",
+    "Email address template" : "이메일 주소 형식",
+    "IMAP" : "IMAP",
+    "User" : "사용자",
+    "Host" : "호스트",
+    "Port" : "포트",
+    "SMTP" : "SMTP",
+    "Master password" : "마스터 암호",
+    "Use master password" : "마스터 암호 사용",
+    "Sieve" : "Sieve",
+    "Enable sieve integration" : "Sieve 통합 활성화",
+    "LDAP aliases integration" : "LDAP 별칭 통합",
+    "Enable LDAP aliases integration" : "LDAP 별칭 통합 활성화",
+    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP 별칭에 대한 통합 체계가 이메일 별칭 프로비전을 위해 설정된 LDAP 디렉토리로부터 속성값을 읽습니다.",
+    "LDAP attribute for aliases" : "별칭에 대한 LDAP 속성",
+    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "이메일 별칭 프로비전을 위한 복수의 속성값. 각 값에 대해 별칭이 생성됩니다. Nextcloud에 존재하는 별칭 중 LDAP 디렉토리에 없는 것은 삭제됩니다.",
+    "Save Config" : "설정 저장",
+    "Unprovision & Delete Config" : "프로비전 해제 및 삭제 설정",
+    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID%와(과) %EMAIL%이(가) 사용자의 UID와 이메일로 대체됩니다",
+    "With the settings above, the app will create account settings in the following way:" : "상단의 설정을 통해, 앱은 다음의 방법으로 계정 설정을 생성합니다: ",
+    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "제공된 PKCS #12 인증서는 최소 하나의 인증서와 정확히 하나의 개인 키를 포함하여야 합니다.",
+    "Failed to import the certificate. Please check the password." : "인증서를 불러올 수 없음. 암호를 확인하십시오.",
+    "Certificate imported successfully" : "인증서를 성공적으로 불러옴",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "인증서를 불러올 수 없음. 개인 키와 인증서의 연동 및 개인 키의 암구호 미사용 여부를 확인하십시오.",
+    "Failed to import the certificate" : "인증서를 가져올 수 없음",
+    "S/MIME certificates" : "S/MIME 인증서",
+    "Certificate name" : "인증서 이름",
+    "E-mail address" : "이메일 주소",
+    "Valid until" : "만료 기간:",
+    "Delete certificate" : "인증서 삭제",
+    "No certificate imported yet" : "가져온 인증서 없음",
+    "Import certificate" : "인증서 가져오기",
+    "Import S/MIME certificate" : "S/MIME 인증서 가져오기",
+    "PKCS #12 Certificate" : "PKCS #12 인증서",
+    "PEM Certificate" : "PEM 인증서",
+    "Certificate" : "인증서",
+    "Private key (optional)" : "개인 키 (선택사항)",
+    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "개인 키는 이 인증서를 사용하여 서명하거나 암호화한 이메일을 보낼 때만 사용됩니다",
+    "Submit" : "제출",
+    "Account connected" : "계정 연결됨",
+    "You can close this window" : "윈도우를 닫으셔도 됩니다",
+    "Connect your mail account" : "메일 계정에 연결",
+    "To add a mail account, please contact your administrator." : "이메일 계정 추가는 관리자에게 문의하십시오.",
     "All" : "모두",
     "Drafts" : "임시 보관함",
     "Favorites" : "즐겨찾기",
@@ -478,6 +643,8 @@ OC.L10N.register(
     "Redirect" : "넘겨주기",
     "The link leads to %s" : "이 링크가 %s을(를) 향함",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "해당 페이지를 방문하지 않으려면 <a href=\"%s\">메일</a>로 돌아갈 수 있습니다.",
-    "Continue to %s" : "%s(으)로 이동"
+    "Continue to %s" : "%s(으)로 이동",
+    "Draft: " : "초안:",
+    "Actions" : "동작"
 },
 "nplurals=1; plural=0;");
