@@ -12,6 +12,7 @@ OC.L10N.register(
     "None" : "Keng",
     "Go back" : "Zeréckgoen",
     "Cancel" : "Ofbriechen",
+    "Accounts" : "Accounts",
     "General" : "Allgemeng",
     "Delete" : "Läschen",
     "Search" : "Search",
@@ -42,7 +43,13 @@ OC.L10N.register(
     "Date" : "Date",
     "Tags" : "Tags",
     "Custom" : "Individualiséier",
+    "Reset" : "Zeréck setzen",
+    "Client ID" : "Client ID",
+    "User" : "User",
+    "Host" : "Host",
+    "Port" : "Port",
     "All" : "All",
-    "Favorites" : "Favoriten"
+    "Favorites" : "Favoriten",
+    "Actions" : "Aktiounen"
 },
 "nplurals=2; plural=(n != 1);");
