@@ -167,7 +167,6 @@ OC.L10N.register(
     "Set reminder for next week" : "Nustatyti priminimą kitą savaitę",
     "Could not delete message" : "Nepavyko ištrinti laiško",
     "Could not archive message" : "Nepavyko archyvuoti laiško",
-    "Draft: " : "Juodraštis: ",
     "Encrypted message" : "Šifruotas laiškas",
     "This message is unread" : "Šis laiškas yra neskaitytas",
     "Unfavorite" : "Nebežymėti kaip mėgstamą",
@@ -318,12 +317,102 @@ OC.L10N.register(
     "Signature …" : "Parašas…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Jūsų parašas yra didesnis nei 2 MB. Tai gali paveikti redaktoriaus našumą.",
     "Save signature" : "Įrašyti parašą",
+    "Message source" : "Pirminis laiško kodas",
     "An error occurred, unable to rename the tag." : "Įvyko klaida, nepavyko pervadinti žymos.",
     "Delete tag" : "Ištrinti žymą",
     "Tag name is a hidden system tag" : "Žymos pavadinimas yra paslėpta sistemos žyma",
     "Tag already exists" : "Žyma jau yra",
     "Tag name cannot be empty" : "Žymos pavadinimas negali būti tuščias",
     "An error occurred, unable to create the tag." : "Įvyko klaida, nepavyko sukurti žymos.",
+    "Add default tags" : "Pridėti numatytąsias žymas",
+    "Add tag" : "Pridėti žymą",
+    "Saving tag …" : "Įrašoma žyma…",
+    "Task created" : "Užduotis sukurta",
+    "Could not create task" : "Nepavyko sukurti užduoties",
+    "Not found" : "Nerasta",
+    "This message was encrypted by the sender before it was sent." : "Siuntėjas, prieš išsiųsdamas šį laišką, jį užšifravo.",
+    "Reply all" : "Atsakyti visiems",
+    "Disable reminder" : "Išjungti priminimą",
+    "Unsubscribe" : "Atsisakyti prenumeratos",
+    "Reply to sender only" : "Atsakyti tik siuntėjui",
+    "Mark as unread" : "Žymėti kaip neskaitytą",
+    "Mark as read" : "Žymėti kaip skaitytą",
+    "Unsubscribe via link" : "Atsisakyti prenumeratos per nuorodą",
+    "Unsubscribe via email" : "Atsisakyti prenumeratos per el. paštą",
+    "Could not remove trusted sender {sender}" : "Nepavyko pašalinti patikimo siuntėjo {sender}",
+    "No senders are trusted at the moment." : "Šiuo metu nėra patikimų siuntėjų.",
+    "Untitled event" : "Įvykis be pavadinimo",
+    "(organizer)" : "(organizatorius)",
+    "Import into {calendar}" : "Importuoti į {calendar}",
+    "Event imported into {calendar}" : "Įvykis importuotas į {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Skrydis {flightNr} iš {depAirport} į {arrAirport}",
+    "Airplane" : "Lėktuvas",
+    "Reservation {id}" : "Rezervacija {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iš {depStation} į {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Traukinys iš {depStation} į {arrStation}",
+    "Train" : "Traukinys",
+    "Delete action" : "Ištrinti veiksmą",
+    "Recipient" : "Gavėjas",
+    "Delete filter" : "Ištrinti filtrą",
+    "Delete mail filter {filterName}?" : "Ištrinti pašto filtrą {filterName}?",
+    "New filter" : "Naujas filtras",
+    "Filter saved" : "Filtras įrašytas",
+    "Could not save filter" : "Nepavyko įrašyti filtro",
+    "Filter deleted" : "Filtras ištrintas",
+    "Could not delete filter" : "Nepavyko ištrinti filtro",
+    "matches" : "atitinka",
+    "Priority" : "Pirmenybė",
+    "Enable filter" : "Įjungti filtrą",
+    "Save filter" : "Įrašyti filtrą",
+    "Error saving config" : "Klaida įrašant konfigūraciją",
+    "Mail app" : "Pašto programėlė",
+    "The mail app allows users to read mails on their IMAP accounts." : "Pašto programėlė leidžia naudotojams skaityti laiškus savo IMAP paskyrose.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Čia galite rasti egzemplioriaus masto nustatymus. Specifinius naudotojo nustatymus galite rasti pačioje programėlėje (apatiniame kairiajame kampe).",
+    "Add new config" : "Pridėti naują konfigūraciją",
+    "Allow additional mail accounts" : "Leisti papildomas pašto paskyras",
+    "Gmail integration" : "„Gmail“ integracija",
+    "Microsoft integration" : "„Microsoft“ integracija",
+    "The original message will be attached as a \"message/rfc822\" attachment." : "Pradinis laiškas bus pridėtas kaip priedas „message/rfc822“.",
+    "Reset" : "Atstatyti",
+    "Google integration configured" : "„Google“ integracija sukonfigūruota",
+    "Could not configure Google integration" : "Nepavyko sukonfigūruoti „Google“ integracijos",
+    "Google integration unlinked" : "„Google“ integracija atsieta",
+    "Could not unlink Google integration" : "Nepavyko atsieti „Google“ integracijos",
+    "Client ID" : "Kliento ID",
+    "Client secret" : "Kliento paslaptis",
+    "Unlink" : "Atsieti",
+    "Microsoft integration configured" : "„Microsoft“ integracija sukonfigūruota",
+    "Could not configure Microsoft integration" : "Nepavyko sukonfigūruoti „Microsoft“ integracijos",
+    "Microsoft integration unlinked" : "„Microsoft“ integracija atsieta",
+    "Could not unlink Microsoft integration" : "Nepavyko atsieti „Microsoft“ integracijos",
+    "Email: {email}" : "El. paštas: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} ties {host}:{port} ({ssl} šifravimas)",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} ties {host}:{port} ({ssl} šifravimas)",
+    "Email address template" : "El. pašto adreso šablonas",
+    "IMAP" : "IMAP",
+    "User" : "Naudotojas",
+    "Host" : "Serveris",
+    "Port" : "Prievadas",
+    "SMTP" : "SMTP",
+    "Save Config" : "Įrašyti konfigūraciją",
+    "With the settings above, the app will create account settings in the following way:" : "Naudodama aukščiau esančius nustatymus, programėlė sukurs paskyrai nustatymus štai tokiu būdu: ",
+    "Certificate imported successfully" : "Liudijimas sėkmingai importuotas",
+    "Failed to import the certificate" : "Nepavyko importuoti liudijimo",
+    "S/MIME certificates" : "S/MIME liudijimai",
+    "Certificate name" : "Liudijimo pavadinimas",
+    "E-mail address" : "El. pašto adresas",
+    "Valid until" : "Galioja iki",
+    "Delete certificate" : "Ištrinti liudijimą",
+    "Import certificate" : "Importuoti liudijimą",
+    "Import S/MIME certificate" : "Importuoti S/MIME liudijimą",
+    "PKCS #12 Certificate" : "PKCS #12 liudijimas",
+    "PEM Certificate" : "PEM liudijimas",
+    "Certificate" : "Liudijimas",
+    "Submit" : "Pateikti",
+    "Account connected" : "Paskyra prijungta",
+    "You can close this window" : "Galite užverti šį langą",
+    "Connect your mail account" : "Priregistruoti elektroninio pašto paskyrą",
+    "To add a mail account, please contact your administrator." : "Norėdami pridėti pašto paskyrą, susisiekite su savo administratoriumi.",
     "All" : "Visos",
     "Drafts" : "Juodraščiai",
     "Favorites" : "Mėgstami",
@@ -352,6 +441,9 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jeigu per artimiausias kelias sekundes nesate automatiškai nukreipiami, spustelėkite čia.",
     "Redirect" : "Peradresuoti",
     "The link leads to %s" : "Nuoroda veda į %s",
-    "Continue to %s" : "Tęsti į %s"
+    "Continue to %s" : "Tęsti į %s",
+    "Draft: " : "Juodraštis: ",
+    "Actions" : "Veiksmai",
+    "New action" : "Naujas veiksmas"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
