@@ -13,9 +13,11 @@ OC.L10N.register(
     "Connecting" : "Savienojuma izveide",
     "Save" : "Saglabāt",
     "Connect" : "Savienoties",
+    "Configuration discovery failed. Please use the manual settings" : "Konfigurācijas atklāšana neizdevās. Lūgums izmantot pašrocīgu iestatīšanu",
     "Password required" : "Nepieciešama parole",
     "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Konts atjaunināts. Lūgums sekot uznirstošajām norādēm, lai atkārtoti savienotu savu Google kontu",
     "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "Konts atjaunināts. Lūgums sekot uznirstošajām norādēm, lai atkārtoti savienotu savu Microsoft kontu",
+    "Configuration discovery temporarily not available. Please try again later." : "Konfigurācijas atklāšana īslaicīgi nav pieejama. Lūgums vēlāk mēģināt vēlreiz.",
     "Auto" : "Automātiski",
     "Name" : "Nosaukums",
     "Mail address" : "E-pasta adrese",
@@ -105,6 +107,7 @@ OC.L10N.register(
     "Rename" : "Pārdēvēt",
     "Subscribed" : "Abonēts",
     "New message" : "Jauna ziņa",
+    "Draft" : "Melnraksts",
     "Reply" : "Atbildēt",
     "Retry" : "Mēģināt vēlreiz",
     "Autoresponder follows system settings" : "Automātiskais atbildētājs ievēro sistēmas iestatījumus",
@@ -124,6 +127,25 @@ OC.L10N.register(
     "Delete tag" : "Izdzēst birku",
     "Tag name is a hidden system tag" : "Birkas nosaukums ir slēpta sistēmas birka",
     "Tag already exists" : "Birka jau pastāv",
+    "Not found" : "Nav atrasts",
+    "Untitled event" : "Nenosaukts notikums",
+    "Recipient" : "Saņēmējs",
+    "Operator" : "Operators",
+    "contains" : "saturs",
+    "matches" : "atbilst",
+    "Priority" : "Prioritāte",
+    "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
+    "Reset" : "Atiestatīt",
+    "Client ID" : "Klienta ID",
+    "User" : "Lietotājs",
+    "Host" : "Resursdators",
+    "Port" : "Ports",
+    "Valid until" : "Derīgs līdz",
+    "Certificate" : "Sertifikāts",
+    "Submit" : "Iesniegt",
+    "Account connected" : "Konts sasaistīts",
+    "You can close this window" : "Šo logu var aizvērt.",
+    "Connect your mail account" : "Pievienot savu e-pasta kontu",
     "All" : "Visi",
     "Drafts" : "Melnraksti",
     "Favorites" : "Izlases vienumi",
@@ -143,6 +165,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jāklikšķina šeit, ja nenotiek automātiska pārvirzīšana dažu sekunžu laikā.",
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
-    "Continue to %s" : "Turpināt %s"
+    "Continue to %s" : "Turpināt %s",
+    "Actions" : "Darbības"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
