@@ -173,7 +173,6 @@ OC.L10N.register(
     "Set reminder for next week" : "Постави потсетник за наредната недела",
     "No trash mailbox configured" : "Нема конфигурирано сандаче за отпадоци",
     "Could not delete message" : "Неможе да се избрише пораката",
-    "Draft: " : "Шаблон:",
     "This message is unread" : "Оваа порака не е прочитана",
     "Favorite" : "Омилени",
     "Unread" : "Непрочитана",
@@ -342,11 +341,64 @@ OC.L10N.register(
     "Signature …" : "Потпис ...",
     "Save signature" : "Зачувај потпис",
     "Place signature above quoted text" : "Постави го потписот над цитираниот текст",
+    "Message source" : "Извор на пораката",
     "An error occurred, unable to rename the tag." : "Настана грешка, неможе да се преименува ознака.",
     "Saving new tag name …" : "Зачувување на ново име на ознака ...",
     "Tag name is a hidden system tag" : "Името на ознаката е сокриена системска ознака",
     "Tag already exists" : "Тагот веќе постои",
     "An error occurred, unable to create the tag." : "Настана грешка, неможе да се креира ознака.",
+    "Add default tags" : "Додади стандардни ознаки",
+    "Add tag" : "Додади ознака",
+    "Saving tag …" : "Зачувување ознака …",
+    "Could not load your message thread" : "Неможат да се преземат информации за пораката",
+    "Not found" : "Не е пронајдено",
+    "Reply all" : "Одговори на сите",
+    "Reply to sender only" : "Одговор само до испраќачот",
+    "Mark as unfavorite" : "Од-означи омилена",
+    "Mark as favorite" : "Означи како омилена",
+    "Mark as unread" : "Означи како непрочитано",
+    "Mark as read" : "Означи како прочитано",
+    "Untitled event" : "Неименуван настан",
+    "(organizer)" : "(organizer)",
+    "Import into {calendar}" : "Увези во {calendar}",
+    "Event imported into {calendar}" : "Настанот е увезен во {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Лет {flightNr} од {depAirport} до {arrAirport}",
+    "Airplane" : "Авион",
+    "Reservation {id}" : "Резервација {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} од {depStation} до {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Воз од  {depStation} до {arrStation}",
+    "Train" : "Воз",
+    "Flag" : "Знаме",
+    "matches" : "се совпаѓа",
+    "Priority" : "Приоритет",
+    "Mail app" : "Апликација Електронска пошта",
+    "The mail app allows users to read mails on their IMAP accounts." : "Апликацијата за електронска пошта дозволува на корисниците да ги читаат својте пораки од IMAP сметки.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Овде може да се пронајде поопшитно прилагодување. Специфични параметри за корисниците може да се пронајдат во самата апликација (доле-лево).",
+    "Gmail integration" : "Gmail интеграција",
+    "Microsoft integration" : "Microsoft интеграција",
+    "Reset" : "Ресетирање",
+    "Client ID" : "Клиент ИД",
+    "Client secret" : "Тајна на клиент",
+    "Domain Match: {provisioningDomain}" : "Софпаѓање на домен: {provisioningDomain}",
+    "Email: {email}" : "Е-пошта: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на {host}:{port} ({ssl} енкрипција)",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} на {host}:{port} ({ssl} енкрипција)",
+    "Configuration for \"{provisioningDomain}\"" : "Конфигурација за \"{provisioningDomain}\"",
+    "IMAP" : "IMAP",
+    "User" : "Корисник",
+    "Host" : "Домаќин",
+    "Port" : "Порта",
+    "SMTP" : "SMTP",
+    "Save Config" : "Зачувај конфигурација",
+    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% и %EMAIL% ќе биде заменето со корнички ID и e-po[ta",
+    "With the settings above, the app will create account settings in the following way:" : "Со овие параметри, апликацијата ќе креира сметки:",
+    "E-mail address" : "Е-пошта адреса",
+    "Valid until" : "Валиден до",
+    "Certificate" : "Сертификат",
+    "Submit" : "Испрати",
+    "Account connected" : "Сметката е поврзана",
+    "You can close this window" : "Можете да го затворите овој прозорец",
+    "Connect your mail account" : "Поврзете ја вашата е-пошта сметка",
     "All" : "Сите",
     "Drafts" : "Шаблони",
     "Favorites" : "Омилени",
@@ -377,6 +429,9 @@ OC.L10N.register(
     "Redirect" : "Пренасочи",
     "The link leads to %s" : "Линкот води кон %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Доколку несакате да ја посетите страната, можете да се вратите кон <a href=\"%s\">Е-пошта</a>.",
-    "Continue to %s" : "Продолжи до %s"
+    "Continue to %s" : "Продолжи до %s",
+    "Draft: " : "Шаблон:",
+    "Actions" : "Акции",
+    "New action" : "Нова акција"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
