@@ -22,6 +22,7 @@ OC.L10N.register(
     "Signature" : "Гарын үсэг",
     "Go back" : "Буцах",
     "Cancel" : "болиулах",
+    "Accounts" : "Accounts",
     "Add mail account" : "шуудангийн хаяг нэмэх",
     "General" : "Ерөнхий",
     "List" : "Жагсаалт",
@@ -66,6 +67,15 @@ OC.L10N.register(
     "Date" : "Он сар өдөр",
     "Tags" : "Tag-үүд",
     "Custom" : "Дурын",
+    "Recipient" : "Хүлээн авагч",
+    "matches" : "тохируулах",
+    "Reset" : "тохируулах",
+    "Client ID" : "Хэрэглэгчийн ID",
+    "Host" : "хост",
+    "Port" : "порт",
+    "Certificate" : "Гэрчилгээ",
+    "Submit" : "мэдэгдэх",
+    "Connect your mail account" : "Таны мэйл бүртгэлийг холбоно",
     "All" : "бүх",
     "Drafts" : "ноорог",
     "Favorites" : "Онцолсон",
@@ -73,6 +83,7 @@ OC.L10N.register(
     "Junk" : "хэрэггүй",
     "Sent" : "илгээсэн",
     "Trash" : "хог",
-    "Error loading message" : "алдаатай ачааллах зурвас"
+    "Error loading message" : "алдаатай ачааллах зурвас",
+    "Actions" : "Үйл ажиллагаа"
 },
 "nplurals=2; plural=(n != 1);");
