@@ -244,7 +244,6 @@ OC.L10N.register(
     "Could not snooze thread" : "Kunne ikke slumre tråd",
     "Thread was unsnoozed" : "Tråden fikk opphevet slumringen",
     "Could not unsnooze thread" : "Kunne ikke oppheve slumring",
-    "Draft: " : "Kladd:",
     "Encrypted message" : "Kryptert melding",
     "This message is unread" : "Meldingen er ulest",
     "Unfavorite" : "Fjern favorittmarkering",
@@ -503,6 +502,7 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Signaturen din er større enn 2 MB. Dette kan påvirke ytelsen til redigeringsprogrammet ditt.",
     "Save signature" : "Lagre signatur",
     "Place signature above quoted text" : "Plasser signatur over sitert tekst",
+    "Message source" : "Melding kilde",
     "An error occurred, unable to rename the tag." : "Det oppsto en feil, kan ikke gi nytt navn til taggen.",
     "Edit name or color" : "Rediger navn eller farge",
     "Saving new tag name …" : "Lagrer nytt tagnavn …",
@@ -513,7 +513,184 @@ OC.L10N.register(
     "Tag already exists" : "Merkelappen finnes allerede",
     "Tag name cannot be empty" : "Navn for merkelapp kan ikke være tom",
     "An error occurred, unable to create the tag." : "Det oppsto en feil, kan ikke opprette taggen.",
+    "Add default tags" : "Legg til standardtags",
+    "Add tag" : "Legg til merkelapp",
+    "Saving tag …" : "Lagrer tag …",
+    "Task created" : "Oppgave opprettet",
+    "Could not create task" : "Kunne ikke opprette oppgave",
+    "No calendars with task list support" : "Ingen kalendere med støtte for oppgavelister",
+    "Summarizing thread failed." : "Sammendrag av tråd feilet",
+    "Could not load your message thread" : "Kunne ikke laste meldingstråden din",
+    "The thread doesn't exist or has been deleted" : "Tråden finnes ikke eller er slettet",
     "Print" : "Skriv ut",
+    "Loading thread" : "Laster tråd",
+    "Not found" : "Ikke funnet",
+    "Encrypted & verified " : "Kryptert og verifisert",
+    "Signature verified" : "Signatur verifisert",
+    "Signature unverified " : "Signatur ikke verifisert",
+    "This message was encrypted by the sender before it was sent." : "Denne meldingen ble kryptert av avsenderen før den ble sendt.",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Denne meldingen inneholder en bekreftet digital S/MIME-signatur. Meldingen ble ikke endret siden den ble sendt.",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meldingen inneholder en ubekreftet digital S/MIME-signatur. Meldingen kan ha blitt endret siden den ble sendt, eller sertifikatet til signataren er ikke klarert.",
+    "Reply all" : "Svar alle",
+    "Unsubscribe request sent" : "Avmeldingsforespørsel sendt",
+    "Could not unsubscribe from mailing list" : "Kunne ikke melde deg av e-postlisten",
+    "Disable reminder" : "Deaktiver påminnelse",
+    "Unsubscribe" : "Avslutt abonnement",
+    "Reply to sender only" : "Svar kun til avsender",
+    "Mark as unfavorite" : "Merk som ufavoritt",
+    "Mark as favorite" : "Merk som favoritt",
+    "Mark as unread" : "Merk som ulest",
+    "Mark as read" : "Merk som lest",
+    "Unsubscribe via link" : "Avslutt abonnement via kobling",
+    "Unsubscribing will stop all messages from the mailing list {sender}" : "Hvis du avslutter abonnementet, stoppes alle meldinger fra adresselisten {avsender}",
+    "Send unsubscribe email" : "Send e-post for avmelding",
+    "Unsubscribe via email" : "Avmeld via e-post",
+    "{name} Assistant" : "{name} Assistent",
+    "Go to latest message" : "Gå til seneste melding",
+    "Go to newest message" : "Gå til nyeste melding",
+    "Thread summary" : "Trådsammendrag",
+    "The message could not be translated" : "Meldingen kan ikke oversettes",
+    "Translation copied to clipboard" : "Oversettelsen kopier til utklippstavlen",
+    "Translation could not be copied" : "Oversettelsen kunne ikke kopieres",
+    "Translate message" : "Oversett melding",
+    "Source language to translate from" : "Kildespråk å oversette fra",
+    "Translate from" : "Oversett fra",
+    "Target language to translate into" : "Målspråk å oversette til",
+    "Translate to" : "Oversett til",
+    "Translating" : "Oversetter",
+    "Copy translated text" : "Kopier oversatt tekst",
+    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Deaktiver oppbevaring av søppelpost ved å la feltet stå tomt eller sette det til 0. Bare e-poster slettet etter at søppeloppbevaring er aktivert vil bli behandlet.",
+    "Could not remove trusted sender {sender}" : "Kunne ikke fjerne pålitelig avsender {sender}",
+    "No senders are trusted at the moment." : "Ingen avsendere er klarert for øyeblikket.",
+    "Untitled event" : "Hendelse uten tittel",
+    "(organizer)" : "(organisator)",
+    "Import into {calendar}" : "Importer til {calender}",
+    "Event imported into {calendar}" : "Hendelse importert til {calender}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Fly {flightNr} fra {depAirport} til {arrAirport}",
+    "Airplane" : "Fly",
+    "Reservation {id}" : "Reservasjon {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}\n ",
+    "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}\n ",
+    "Train" : "Tog",
+    "Flag" : "Flagg",
+    "Recipient" : "Mottaker",
+    "Delete filter" : "Slett filter",
+    "Operator" : "Operator",
+    "contains" : "inneholder",
+    "matches" : "passer",
+    "Filter name" : "Filternavn",
+    "Priority" : "Prioritet",
+    "Successfully updated config for \"{domain}\"" : "Vellykket oppdatert konfigurasjon for «{domain}»",
+    "Error saving config" : "Feil ved lagring av konfigurasjon",
+    "Saved config for \"{domain}\"" : "Lagret konfigurasjon for «{domain}»",
+    "Could not save provisioning setting" : "Kunne ikke lagre klargjørings innstillingen",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Klargjort {count} konto.","Klargjort {count} kontoer."],
+    "There was an error when provisioning accounts." : "Det oppsto en feil under klargjøring av kontoene.",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Vellykket slettet og deaktivert kontoer for «{domain}»",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Feil ved sletting og deaktivering av kontoer for «{domain}»",
+    "Could not save default classification setting" : "Kan ikke lagre standard klassifiseringsinnstilling",
+    "Mail app" : "E-post app",
+    "The mail app allows users to read mails on their IMAP accounts." : "E-post appen lar brukere lese e-poster på IMAP-kontoene sine.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Her kan du finne innstillinger for hele instansen. Bruker spesifikke innstillinger finner du i selve appen (nederst til venstre).",
+    "Account provisioning" : "Konto klargjøring",
+    "A provisioning configuration will provision all accounts with a matching email address." : "En klargjørings konfigurasjon vil klargjøre alle kontoer med en matchende e-postadresse.",
+    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Bruk av jokertegnet (*) i klargjøringsdomenefeltet vil opprette en konfigurasjon som gjelder for alle brukere, forutsatt at de ikke samsvarer med en annen konfigurasjon.",
+    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Klargjørings mekanismen vil prioritere spesifikke domene konfigurasjoner over jokertegnet-domene konfigurasjonen.",
+    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Skulle en ny samsvarende konfigurasjon bli funnet etter at brukeren allerede var klargjort med en annen konfigurasjon, vil den nye konfigurasjonen ha forrang, og brukeren vil bli tilordnet på nytt med konfigurasjonen.",
+    "There can only be one configuration per domain and only one wildcard domain configuration." : "Det kan bare være én konfigurasjon per domene og kun én domene konfigurasjon med jokertegn.",
+    "These settings can be used in conjunction with each other." : "Disse innstillingene kan brukes sammen med hverandre.",
+    "If you only want to provision one domain for all users, use the wildcard (*)." : "Hvis du bare vil klargjøre ett domene for alle brukere, bruk jokertegnet (*).",
+    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Denne innstillingen gir bare mening hvis den bruker samme bruker backend for Nextcloud og e-postserveren til organisasjonen din.",
+    "Provisioning Configurations" : "Klargjørings konfigurasjoner",
+    "Add new config" : "Legg til ny konfig",
+    "Provision all accounts" : "Klargjør alle kontoer",
+    "Allow additional mail accounts" : "Tillat flere e-postkontoer",
+    "Allow additional Mail accounts from User Settings" : "Tillat flere e-postkontoer fra brukerinnstillinger",
+    "Enable text processing through LLMs" : "Aktiver tekstprosessering gjennom LLM-er",
+    "The Mail app can process user data with the help of the configured large language model and provide assistance features like thread summaries, smart replies and event agendas." : "Mail-appen kan behandle brukerdata ved hjelp av den konfigurerte store språkmodellen og gi assistansefunksjoner som trådsammendrag, smarte svar og hendelsesagendaer.",
+    "Enable LLM processing" : "Aktiver LLM-prosessering",
+    "Enable classification by importance by default" : "Aktiver klassifisering etter viktighet som standard",
+    "The Mail app can classify incoming emails by importance using machine learning. This feature is enabled by default but can be disabled by default here. Individual users will still be able to toggle the feature for their accounts." : "E-post-appen kan klassifisere innkommende e-post etter viktighet ved hjelp av maskinlæring. Denne funksjonen er aktivert som standard, men kan deaktiveres som standard her. Enkeltbrukere vil fortsatt kunne veksle mellom funksjonen for kontoene sine.",
+    "Enable classification of important mails by default" : "Aktiver klassifisering etter viktige e-poster som standard",
+    "Anti Spam Service" : "Anti spam tjeneste",
+    "You can set up an anti spam service email address here." : "Du kan sette opp en e-postadresse for antispamtjeneste her.",
+    "Any email that is marked as spam will be sent to the anti spam service." : "Enhver e-post som er merket som spam vil bli sendt til anti spam-tjenesten.",
+    "Gmail integration" : "Gmail-integrering",
+    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail lar brukere få tilgang til e-posten sin via IMAP. Av sikkerhetsgrunner er denne tilgangen bare mulig med en OAuth 2.0-tilkobling eller Google-kontoer som bruker tofaktorautentisering og app-passord.",
+    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Du må registrere en ny klient-ID for en \"nettapplikasjon\" i Google Cloud-konsollen. Legg til URL-adressen {url} som autorisert omdirigerings-URI.",
+    "Microsoft integration" : "Microsoft-integrering",
+    "Successfully set up anti spam email addresses" : "Konfigurer anti spam e-postadresser",
+    "Error saving anti spam email addresses" : "Feil ved lagring av anti spam-e-postadresser",
+    "Successfully deleted anti spam reporting email" : "Vellykket slettet  anti spam rapportering e-post",
+    "Error deleting anti spam reporting email" : "Feil ved sletting av anti spam rapporterings e-post",
+    "Anti Spam" : "Anti Spam",
+    "Add the email address of your anti spam report service here." : "Legg til e-postadressen til din anti spam-rapporttjeneste her.",
+    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "Når du bruker denne innstillingen, vil en rapport-e-post bli sendt til SPAM-rapport serveren når en bruker klikker \"Merk som spam\".",
+    "The original message will be attached as a \"message/rfc822\" attachment." : "Den opprinnelige meldingen vil legges ved som et \"melding/rfc822\"-vedlegg.",
+    "\"Mark as Spam\" Email Address" : "\"Merk som spam\" e-postadresse",
+    "\"Mark Not Junk\" Email Address" : "\"Merk ikke søppelpost\" e-postadresse",
+    "Reset" : "Tilbakestill",
+    "Google integration configured" : "Google-integrasjon konfigurert",
+    "Could not configure Google integration" : "Kunne ikke konfigurere Google-integrasjon",
+    "Google integration unlinked" : "Google-integrasjon koblet fra",
+    "Could not unlink Google integration" : "Kunne ikke koble fra Google-integrasjonen",
+    "Client ID" : "Klient-ID",
+    "Client secret" : "Klient-hemmelighet",
+    "Unlink" : "Fjern koblingen",
+    "Microsoft integration configured" : "Microsoft-integrasjon konfigurert",
+    "Could not configure Microsoft integration" : "Kunne ikke konfigurere Microsoft-integrasjon",
+    "Microsoft integration unlinked" : "Microsoft-integrasjon koblet fra",
+    "Could not unlink Microsoft integration" : "Kunne ikke koble fra Microsoft-integrasjon",
+    "Tenant ID (optional)" : "Leier-ID (valgfritt)",
+    "Domain Match: {provisioningDomain}" : "Domenematch: {provisioningDomain}",
+    "Email: {email}" : "E-post: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} på {host}:{port} ({ssl}-kryptering)",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} på {host}:{port} ({ssl}-kryptering)",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve:  {user} på {host}:{port} ({ssl}-kryptering)",
+    "Configuration for \"{provisioningDomain}\"" : "Konfigurasjon for «{provisioningDomain}»",
+    "Provisioning domain" : "Klargjør domene",
+    "Email address template" : "E-postadresse mal",
+    "IMAP" : "IMAP",
+    "User" : "Bruker",
+    "Host" : "Server",
+    "Port" : "Port",
+    "SMTP" : "SMTP",
+    "Master password" : "Hovedpassord",
+    "Use master password" : "Bruk hovedpassord",
+    "Sieve" : "Sieve",
+    "Enable sieve integration" : "Aktiver sieve integrasjon",
+    "LDAP aliases integration" : "Integrasjon av LDAP-aliaser",
+    "Enable LDAP aliases integration" : "Aktiver integrasjon av LDAP-aliaser",
+    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "LDAP alias-integrasjonen leser et attributt fra den konfigurerte LDAP-katalogen for å klargjøre e-post aliaser.",
+    "LDAP attribute for aliases" : "LDAP attributt for aliaser",
+    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Et attributt med flere verdier for klargjøring av e-post aliaser. For hver verdi opprettes et alias. Aliaser som eksisterer i Nextcloud som ikke er i LDAP katalogen, slettes.",
+    "Save Config" : "Lagre konfigurasjon",
+    "Unprovision & Delete Config" : "Opphev tilordning og slett konfigurasjon",
+    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% og %E MAIL% vil bli erstattet med brukerens UID og e-post",
+    "With the settings above, the app will create account settings in the following way:" : "Med innstillingene ovenfor vil appen opprette konto innstillinger på følgende måte:",
+    "The provided PKCS #12 certificate must contain at least one certificate and exactly one private key." : "Det angitte PKCS #12-sertifikatet må inneholde minst ett sertifikat og nøyaktig én privat nøkkel.",
+    "Failed to import the certificate. Please check the password." : "Kunne ikke importere sertifikatet. Vennligst sjekk passordet.",
+    "Certificate imported successfully" : "Sertifikatet ble importert",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Kan ikke importere sertifikatet. Forsikre deg om at den private nøkkelen samsvarer med sertifikatet og ikke er beskyttet av en passordfrase.",
+    "Failed to import the certificate" : "Kunne ikke importere sertifikatet",
+    "S/MIME certificates" : "S/MIME-sertifikater",
+    "Certificate name" : "Sertifikatnavn",
+    "E-mail address" : "E-postadresse",
+    "Valid until" : "Gyldig til",
+    "Delete certificate" : "Slett sertifikat",
+    "No certificate imported yet" : "Ingen sertifikat importert enda",
+    "Import certificate" : "Importer sertifikat",
+    "Import S/MIME certificate" : "Importer S/MIME-sertifikat",
+    "PKCS #12 Certificate" : "PKCS #12-sertifikat",
+    "PEM Certificate" : "PEM-sertifikat",
+    "Certificate" : "Sertifikat",
+    "Private key (optional)" : "Privat nøkkel (valgfritt)",
+    "The private key is only required if you intend to send signed and encrypted emails using this certificate." : "Den private nøkkelen er bare nødvendig hvis du har tenkt å sende signerte og krypterte e-postmeldinger ved hjelp av dette sertifikatet.",
+    "Submit" : "Send inn",
+    "Account connected" : "Konto er koblet",
+    "You can close this window" : "Du kan lukke dette vinduet",
+    "Connect your mail account" : "Koble til din e-postkonto",
+    "To add a mail account, please contact your administrator." : "For å legge til en e-postkonto, vennligst kontakt administratoren.",
     "All" : "Alle",
     "Drafts" : "Kladder",
     "Favorites" : "Favoritter",
@@ -549,6 +726,9 @@ OC.L10N.register(
     "Redirect" : "Videresend",
     "The link leads to %s" : "Denne lenken leder til %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke vil besøke den siden, kan du gå tilbake til <a href=\"%s\">E-post</a>",
-    "Continue to %s" : "Fortsett til %s"
+    "Continue to %s" : "Fortsett til %s",
+    "Draft: " : "Kladd:",
+    "Actions" : "Handlinger",
+    "New action" : "Ny handling"
 },
 "nplurals=2; plural=(n != 1);");
