@@ -12,6 +12,7 @@ OC.L10N.register(
     "None" : "Ingen",
     "Signature" : "Signatur",
     "Cancel" : "Avbryt",
+    "Accounts" : "Accounts",
     "General" : "Generelt",
     "Keyboard shortcuts" : "Tastatursnarvegar",
     "Delete" : "Ta bort",
@@ -37,9 +38,17 @@ OC.L10N.register(
     "Close" : "Lat att",
     "Date" : "Dato",
     "Tags" : "Emneord",
+    "Recipient" : "Mottakar",
+    "contains" : "inneheld",
+    "Client ID" : "Klient-ID",
+    "User" : "Bruker",
+    "Host" : "Tenar",
+    "Port" : "Port",
+    "Certificate" : "Sertifikat",
     "All" : "Alle",
     "Favorites" : "Favorit",
     "Sent" : "Sendt",
-    "Message sent" : "Melding sendt"
+    "Message sent" : "Melding sendt",
+    "Actions" : "Handlingar"
 },
 "nplurals=2; plural=(n != 1);");
