@@ -29,6 +29,7 @@ OC.L10N.register(
     "Go back" : "Revenir en arrière",
     "Email address" : "Adreça mail",
     "Cancel" : "Anullar",
+    "Accounts" : "Accounts",
     "General" : "Generals",
     "List" : "Tièra",
     "Register" : "S'inscriure",
@@ -79,6 +80,22 @@ OC.L10N.register(
     "Date" : "Data",
     "Tags" : "Etiquetas",
     "Custom" : "Personalizats",
+    "Mark as unread" : "Marcar coma pas legit",
+    "Mark as read" : "Marcar coma legit",
+    "Translate message" : "Traduire lo messatge",
+    "Translating" : "Traduccion",
+    "Untitled event" : "Eveniment sens títol",
+    "Train" : "Tren",
+    "Flag" : "Drapèu",
+    "Reset" : "Reïnicializar",
+    "Client ID" : "ID client",
+    "User" : "Utilizator",
+    "Host" : "Òste",
+    "Port" : "Pòrt",
+    "Valid until" : "Valid fins a",
+    "Certificate" : "Certificat",
+    "Submit" : "Transmetre",
+    "Account connected" : "Compte connectat",
     "All" : "Tot",
     "Drafts" : "Borrolhons",
     "Favorites" : "Favorits",
@@ -91,6 +108,7 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "Message sent" : "Messatge mandat",
     "Error loading message" : "Error al moment del cargament del messatge",
-    "Continue to %s" : "Contunhar cap a %s"
+    "Continue to %s" : "Contunhar cap a %s",
+    "Actions" : "Accions"
 },
 "nplurals=2; plural=(n > 1);");
