@@ -200,7 +200,6 @@ OC.L10N.register(
     "No trash mailbox configured" : "Nie skonfigurowano skrzynki pocztowej dla kosza",
     "Could not delete message" : "Nie udało się usunąć wiadomości",
     "Could not archive message" : "Nie udało się zarchiwizować wiadomości",
-    "Draft: " : "Wersja robocza:",
     "Encrypted message" : "Zaszyfrowana wiadomość",
     "This message is unread" : "Ta wiadomość jest nieprzeczytana",
     "Unfavorite" : "Nie ulubione",
@@ -419,12 +418,151 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Twój podpis jest większy niż 2 MB. Może to wpłynąć na wydajność Twojego edytora.",
     "Save signature" : "Zapisz podpis",
     "Place signature above quoted text" : "Umieść podpis nad cytowanym tekstem",
+    "Message source" : "Źródło wiadomości",
     "An error occurred, unable to rename the tag." : "Wystąpił błąd, nie można zmienić nazwy etykiety.",
     "Saving new tag name …" : "Zapisywanie nowej nazwy etykiety…",
     "Delete tag" : "Usuń etykiety",
     "Tag name is a hidden system tag" : "Nazwa etykiety jest ukrytej etykiety systemowej",
     "Tag already exists" : "Tag już istnieje",
     "An error occurred, unable to create the tag." : "Wystąpił błąd, nie można utworzyć etykiety.",
+    "Add default tags" : "Dodaj etykiety domyślne",
+    "Add tag" : "Dodaj etykietę",
+    "Saving tag …" : "Zapisywanie etykiety…",
+    "Could not load your message thread" : "Nie można wczytać wątku wiadomości",
+    "The thread doesn't exist or has been deleted" : "Wątek nie istnieje lub został usunięty",
+    "Loading thread" : "Wczytywanie wątku",
+    "Not found" : "Nie znaleziono",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Ta wiadomość zawiera zweryfikowany podpis cyfrowy S/MIME. Wiadomość nie została zmieniona od czasu jej wysłania.",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Ta wiadomość zawiera niezweryfikowany cyfrowy podpis S/MIME. Wiadomość mogła zostać zmieniona od czasu jej wysłania lub certyfikat osoby podpisującej jest niezaufany.",
+    "Reply all" : "Odpowiedz wszystkim",
+    "Unsubscribe" : "Wypisz się",
+    "Reply to sender only" : "Odpowiedz tylko nadawcy",
+    "Mark as unfavorite" : "Oznacz jako nieulubione",
+    "Mark as favorite" : "Oznacz jako nieulubione",
+    "Mark as unread" : "Oznacz jako nieprzeczytane",
+    "Mark as read" : "Oznacz jako przeczytane",
+    "The message could not be translated" : "Nie udało się przetłumaczyć wiadomości",
+    "Translation copied to clipboard" : "Tłumaczenie skopiowane do schowka",
+    "Translation could not be copied" : "Nie można skopiować tłumaczenia",
+    "Translate message" : "Przetłumacz wiadomość",
+    "Source language to translate from" : "Język źródłowy, z którego chcesz tłumaczyć",
+    "Translate from" : "Przetłumacz z",
+    "Target language to translate into" : "Język docelowy, na który chcesz tłumaczyć",
+    "Translate to" : "Przetłumacz na",
+    "Translating" : "Tłumaczenie",
+    "Copy translated text" : "Kopiuj przetłumaczony tekst",
+    "Could not remove trusted sender {sender}" : "Nie udało się usunąć zaufanego nadawcy {sender}",
+    "No senders are trusted at the moment." : "W tej chwili żaden nadawca nie jest zaufany.",
+    "Untitled event" : "Wydarzenie bez tytułu",
+    "(organizer)" : "(organizator)",
+    "Import into {calendar}" : "Importuj do {calendar}",
+    "Event imported into {calendar}" : "Wydarzenie zaimportowane do {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Lot {flightNr} z {depAirport} do {arrAirport}",
+    "Airplane" : "Samolot",
+    "Reservation {id}" : "Rezerwacja {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} z {depStation} do {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Pociąg z {depStation} do {arrStation}",
+    "Train" : "Pociąg",
+    "Flag" : "Flaga",
+    "Recipient" : "Odbiorca",
+    "Operator" : "Operator",
+    "contains" : "zawiera",
+    "matches" : "pasuje",
+    "Priority" : "Priorytet",
+    "Successfully updated config for \"{domain}\"" : "Pomyślnie zaktualizowano konfigurację dla \"{domain}\"",
+    "Error saving config" : "Błąd podczas zapisywania konfiguracji",
+    "Saved config for \"{domain}\"" : "Zapisana konfiguracja dla \"{domain}\"",
+    "Could not save provisioning setting" : "Nie udało się zapisać ustawienia zabezpieczenia",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Pomyślnie zabezpieczono {count} konto.","Pomyślnie zabezpieczono {count} konta.","Pomyślnie zabezpieczono {count} kont.","Pomyślnie zabezpieczono {count} kont."],
+    "There was an error when provisioning accounts." : "Wystąpił błąd podczas zabezpieczania kont.",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Pomyślnie usunięto i wyczyszczono zabezpieczenie kont dla domeny \"{domain}\"",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Błąd podczas usuwania i czyszczenia zabezpieczenia kont dla domeny \"{domain}\"",
+    "Mail app" : "Aplikacja poczty",
+    "The mail app allows users to read mails on their IMAP accounts." : "Aplikacja poczty pozwala użytkownikom czytać wiadomości e-mail na kontach IMAP.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Tutaj możesz znaleźć ustawienia dotyczące całej instancji. Ustawienia użytkownika można znaleźć w samej aplikacji (lewy dolny róg).",
+    "Account provisioning" : "Zabezpieczanie konta",
+    "A provisioning configuration will provision all accounts with a matching email address." : "Konfiguracja zabezpieczenia zapewni zabezpieczenie wszystkim kontom z pasujący adresem e-mail.",
+    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Użycie symbolu wieloznacznego (*) w polu domeny zabezpieczonej spowoduje utworzenie konfiguracji, która będzie obowiązywać wszystkich użytkowników, pod warunkiem, że nie odpowiadają one innej konfiguracji.",
+    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Mechanizm zabezpieczenia będzie nadawać priorytet konkretnym konfiguracjom domeny w stosunku do konfiguracji domeny z symbolem wieloznacznym.",
+    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Jeśli zostanie znaleziona nowa pasująca konfiguracja po tym, jak użytkownik zabezpieczył już inną konfiguracją, to nowa konfiguracja będzie miała pierwszeństwo oraz użytkownik zostanie ponownie zabezpieczony tą konfiguracją.",
+    "There can only be one configuration per domain and only one wildcard domain configuration." : "W każdej domenie może być tylko jedna konfiguracja i tylko jedna konfiguracja domeny z symbolem wieloznacznym.",
+    "These settings can be used in conjunction with each other." : "Te ustawienia mogą być używane w połączeniu ze sobą.",
+    "If you only want to provision one domain for all users, use the wildcard (*)." : "Jeśli chcesz zabezpieczyć tylko jedną domenę wszystkim użytkownikom, użyj symbolu wieloznacznego (*).",
+    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Ustawienie ma największy sens tylko wtedy, gdy używasz tego samego zaplecza użytkownika na serwerze Nextcloud i serwerze pocztowym swojej organizacji.",
+    "Provisioning Configurations" : "Konfiguracje zabezpieczenia",
+    "Add new config" : "Dodaj nową konfigurację",
+    "Provision all accounts" : "Zabezpiecz wszystkie konta",
+    "Allow additional mail accounts" : "Zezwalaj na dodatkowe konta pocztowe",
+    "Allow additional Mail accounts from User Settings" : "Zezwalaj na dodatkowe konta pocztowe w Ustawieniach użytkownika",
+    "Anti Spam Service" : "Usługa antyspamowa",
+    "You can set up an anti spam service email address here." : "Tutaj możesz ustawić adres e-mail usługi antyspamowej.",
+    "Any email that is marked as spam will be sent to the anti spam service." : "Każdy e-mail oznaczony jako spam zostanie wysłany do usługi antyspamowej.",
+    "Gmail integration" : "Integracja z Gmailem",
+    "Gmail allows users to access their email via IMAP. For security reasons this access is only possible with an OAuth 2.0 connection or Google accounts that use two-factor authentication and app passwords." : "Gmail umożliwia użytkownikom dostęp do poczty e-mail za pośrednictwem protokołu IMAP. Ze względów bezpieczeństwa dostęp ten jest możliwy tylko za pomocą połączenia OAuth 2.0 lub kont Google korzystających z uwierzytelniania dwuskładnikowego i haseł do aplikacji.",
+    "You have to register a new Client ID for a \"Web application\" in the Google Cloud console. Add the URL {url} as authorized redirect URI." : "Musisz zarejestrować nowy ID klienta dla \"Aplikacji internetowej\" w konsoli Google Cloud. Dodaj adres URL {url} jako identyfikator URI autoryzowanego przekierowania.",
+    "Microsoft integration" : "Integracja Microsoft",
+    "Successfully set up anti spam email addresses" : "Pomyślnie skonfigurowane antyspamowe adresy e-mail",
+    "Error saving anti spam email addresses" : "Błąd podczas zapisywania antyspamowych adresów e-mail",
+    "Successfully deleted anti spam reporting email" : "Pomyślnie usunięto e-mail z raportami antyspamowymi",
+    "Error deleting anti spam reporting email" : "Błąd podczas usuwania e-maila z raportami antyspamowymi",
+    "Anti Spam" : "Antyspam",
+    "Add the email address of your anti spam report service here." : "Dodaj tutaj adres e-mail usługi raportowania antyspamowego.",
+    "When using this setting, a report email will be sent to the SPAM report server when a user clicks \"Mark as spam\"." : "W przypadku korzystania z tego ustawienia e-mail z raportem zostanie wysłany do serwera zgłaszania spamu, gdy użytkownik kliknie opcję \"Oznacz jako spam\".",
+    "The original message will be attached as a \"message/rfc822\" attachment." : "Oryginalna wiadomość zostanie dołączona jako załącznik \"message/rfc822\".",
+    "\"Mark as Spam\" Email Address" : "Adres e-mail \"Oznacz jako spam\"",
+    "\"Mark Not Junk\" Email Address" : "Adres e-mail \"Oznacz jako nie spam\"",
+    "Reset" : "Resetuj",
+    "Google integration configured" : "Skonfigurowano integrację Google",
+    "Could not configure Google integration" : "Nie można skonfigurować integracji Google",
+    "Google integration unlinked" : "Odłączono integrację z Google",
+    "Could not unlink Google integration" : "Nie można odłączyć integracji Google",
+    "Client ID" : "Identyfikator klienta",
+    "Client secret" : "Tajny klucz klienta",
+    "Unlink" : "Odłącz",
+    "Microsoft integration configured" : "Skonfigurowano integrację Microsoft",
+    "Could not configure Microsoft integration" : "Nie można skonfigurować integracji Microsoft",
+    "Microsoft integration unlinked" : "Odłączono integrację Microsoft",
+    "Could not unlink Microsoft integration" : "Nie można odłączyć integracji Microsoft",
+    "Tenant ID (optional)" : "ID najemcy (opcjonalnie)",
+    "Domain Match: {provisioningDomain}" : "Dopasowanie domeny: {provisioningDomain}",
+    "Email: {email}" : "E-mail: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} na {host}:{port} (szyfrowanie {ssl})",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} na {host}:{port} (szyfrowanie {ssl})",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} na {host}:{port} (szyfrowanie {ssl})",
+    "Configuration for \"{provisioningDomain}\"" : "Konfiguracja dla \"{provisioningDomain}\"",
+    "Provisioning domain" : "Zabezpieczenie domeny",
+    "Email address template" : "Szablon adresu e-mail",
+    "IMAP" : "IMAP",
+    "User" : "Użytkownik",
+    "Host" : "Host",
+    "Port" : "Port",
+    "SMTP" : "SMTP",
+    "Sieve" : "Sieve",
+    "Enable sieve integration" : "Włącz integrację Sieve",
+    "LDAP aliases integration" : "Integracja aliasów LDAP",
+    "Enable LDAP aliases integration" : "Włącz integrację aliasów LDAP",
+    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "Integracja aliasów LDAP odczytuje atrybut ze skonfigurowanego katalogu LDAP w celu zabezpieczenia aliasów e-mail.",
+    "LDAP attribute for aliases" : "Atrybut LDAP dla aliasów",
+    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Atrybut wielowartościowy do zabezpieczenia aliasów e-mail. Dla każdej wartości tworzony jest alias. Aliasy istniejące w Nextcloud, których nie ma w katalogu LDAP, są usuwane.",
+    "Save Config" : "Zapisz konfigurację",
+    "Unprovision & Delete Config" : "Cofnij zabezpieczenie i usuń konfigurację",
+    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% i %EMAIL% zostaną zastąpione UID i adresem e-mail użytkownika",
+    "With the settings above, the app will create account settings in the following way:" : "Przy powyższych ustawieniach aplikacja utworzy ustawienia konta w następujący sposób:",
+    "Certificate imported successfully" : "Certyfikat został zaimportowany pomyślnie",
+    "Failed to import the certificate. Please make sure that the private key matches the certificate and is not protected by a passphrase." : "Nie udało się zaimportować certyfikatu. Upewnij się, że klucz prywatny jest zgodny z certyfikatem i nie jest chroniony hasłem.",
+    "Failed to import the certificate" : "Nie udało się zaimportować certyfikatu",
+    "S/MIME certificates" : "Certyfikaty S/MIME",
+    "Certificate name" : "Nazwa certyfikatu",
+    "E-mail address" : "Adres e-mail",
+    "Valid until" : "Ważny do",
+    "Import certificate" : "Importuj certyfikat",
+    "Import S/MIME certificate" : "Importuj certyfikat S/MIME",
+    "Certificate" : "Certyfikat",
+    "Submit" : "Wyślij",
+    "Account connected" : "Połączono z kontem",
+    "You can close this window" : "Możesz zamknąć okno",
+    "Connect your mail account" : "Podłącz konto pocztowe",
+    "To add a mail account, please contact your administrator." : "Aby dodać konto pocztowe, skontaktuj się z administratorem.",
     "All" : "Wszystko",
     "Drafts" : "Wersje robocze",
     "Favorites" : "Ulubione",
@@ -439,6 +577,7 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nowa wiadomość\nod {from}","%n nowe wiadomości \nod {from}","%n nowych wiadomości \nod {from}","%n nowych wiadomości \nod {from}"],
     "Nextcloud Mail" : "Poczta Nextcloud",
+    "Discard changes" : "Odrzuć zmiany",
     "Attachments were not copied. Please add them manually." : "Załączniki nie zostały skopiowane. Dodaj je ręcznie.",
     "Message sent" : "Wiadomość wysłana",
     "Could not send message" : "Nie udało się wysłać wiadomości",
@@ -453,6 +592,9 @@ OC.L10N.register(
     "Redirect" : "Przekieruj",
     "The link leads to %s" : "Link prowadzi do %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Jeśli nie chcesz odwiedzić tej strony, możesz powrócić do <a href=\"%s\">Poczty</a>.",
-    "Continue to %s" : "Kontynuuj do %s"
+    "Continue to %s" : "Kontynuuj do %s",
+    "Draft: " : "Wersja robocza:",
+    "Actions" : "Akcje",
+    "New action" : "Nowa akcja"
 },
 "nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
