@@ -94,7 +94,6 @@ OC.L10N.register(
     "Plain text" : "Texto simples",
     "No messages" : "Sem mensagens",
     "Could not delete message" : "Não foi possível apagar a mensagem",
-    "Draft: " : "Rascunho:",
     "Unfavorite" : "Não favorito",
     "Favorite" : "Favorito",
     "Read" : "Ler",
@@ -181,7 +180,38 @@ OC.L10N.register(
     "Custom" : "Personalizado",
     "Signature …" : "Assinatura...",
     "Save signature" : "Guardar assinatura",
+    "Message source" : "Fonte da mensagem",
     "Tag already exists" : "A etiqueta já existe",
+    "Not found" : "Não  encontrado",
+    "Reply to sender only" : "Resposta apenas ao remetente",
+    "Untitled event" : "Evento sem título",
+    "Import into {calendar}" : "Importar para {calendar}",
+    "Event imported into {calendar}" : "Evento importado para {calendar}",
+    "Airplane" : "Avião",
+    "Reservation {id}" : "Reserva {id}",
+    "Train" : "Comboio",
+    "Recipient" : "Destinatário",
+    "Operator" : "Operador",
+    "contains" : "contém",
+    "matches" : "corresponde",
+    "Filter name" : "Filtrar nome",
+    "Priority" : "Prioridade",
+    "Reset" : "Reiniciar",
+    "Client ID" : "Id. de Cliente",
+    "Client secret" : "Segredo de cliente",
+    "Email: {email}" : "Email: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} em {host}:{port} ({ssl} encryption)",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} em {host}:{port} ({ssl} encryption)",
+    "IMAP" : "IMAP",
+    "User" : "Utilizador",
+    "Host" : "Anfitrião",
+    "Port" : "Porta",
+    "SMTP" : "SMTP",
+    "Valid until" : "Válido até",
+    "Certificate" : "Certificado",
+    "Submit" : "Submeter",
+    "Account connected" : "Conta ligada",
+    "Connect your mail account" : "Ligue a sua conta de e-mail",
     "All" : "Todos",
     "Drafts" : "Rascunhos",
     "Favorites" : "Favoritos",
@@ -203,6 +233,9 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redirecionado dentro de segundos.",
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "A ligação aponta para %s",
-    "Continue to %s" : "Continuar para %s"
+    "Continue to %s" : "Continuar para %s",
+    "Draft: " : "Rascunho:",
+    "Actions" : "Ações",
+    "New action" : "Nova ação"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
