@@ -192,7 +192,6 @@ OC.L10N.register(
     "Could not snooze thread" : "Nu s-a putut amâna conversația",
     "Thread was unsnoozed" : "Conversația a fost reluată",
     "Could not unsnooze thread" : "Nu s-a putut relua conversația",
-    "Draft: " : "Schiță:",
     "Encrypted message" : "Mesaj criptat",
     "This message is unread" : "Mesaj necitit",
     "Unfavorite" : "Elimină favorit",
@@ -410,6 +409,7 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Semnătura este mai mare de 2 MB. Aceasta poate afecta performanța editorului.",
     "Save signature" : "Salvează semnătura",
     "Place signature above quoted text" : "Plasează semnătura deasupra textului citat",
+    "Message source" : "Sursa mesajului",
     "An error occurred, unable to rename the tag." : "Eroare la redenumirea etichetei.",
     "Edit name or color" : "Editează numele sau culoarea",
     "Saving new tag name …" : "Se salvează noul nume al etichetei ...",
@@ -419,6 +419,81 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "Numele este al unei etichete de sistem ascunsă",
     "Tag already exists" : "Eticheta deja există",
     "An error occurred, unable to create the tag." : "Eroare la crearea etichetei.",
+    "Add default tags" : "Adaugă etichetele implicite",
+    "Add tag" : "Adaugă etichetă",
+    "Saving tag …" : "Se salvează eticheta ...",
+    "Task created" : "Sarcina a fost creată",
+    "Could not create task" : "Sarcina nu a putut fi creată",
+    "No calendars with task list support" : "Nu există calendare cu suport pentru liste de sarcini",
+    "Summarizing thread failed." : "Rezumatul conversației a eșuat.",
+    "Could not load your message thread" : "Nu poate fi încărcată conversația",
+    "The thread doesn't exist or has been deleted" : "Conversația nu există sau a fost ștearsă",
+    "Loading thread" : "Se încarcă conversația",
+    "Not found" : "Nu a fost găsit",
+    "Encrypted & verified " : "Criptat și verificat",
+    "Signature verified" : "Semnătură verificată",
+    "Signature unverified " : "Semnătură neverificată",
+    "Reply all" : "Răspunde tuturor",
+    "Unsubscribe request sent" : "Cerere de dezabonare trimisă",
+    "Could not unsubscribe from mailing list" : "A eșuat dezabonarea de la lista de distribuție",
+    "Unsubscribe" : "Dezabonare",
+    "Reply to sender only" : "Răspunde doar expeditorului",
+    "Mark as unfavorite" : "Elimină de la favorite",
+    "Mark as favorite" : "Marchează ca favorit",
+    "Mark as unread" : "Marchează ca necitit",
+    "Mark as read" : "Marchează ca citit",
+    "Unsubscribe via link" : "Dezabonare prin link",
+    "Unsubscribing will stop all messages from the mailing list {sender}" : "Dezabonare va opri mesajele din lista de distribuție {sender}",
+    "Send unsubscribe email" : "Trimite email de dezabonare",
+    "Unsubscribe via email" : "Dezabonare prin email",
+    "{name} Assistant" : "{name} Asistent",
+    "Go to latest message" : "Salt la ultimul mesaj",
+    "Go to newest message" : "Salt la cele mai recente mesaje",
+    "Disable trash retention by leaving the field empty or setting it to 0. Only mails deleted after enabling trash retention will be processed." : "Dezactivați păstrarea în coș lăsând câmpul necompletat sau introducând 0. Vor fi procesate doar mailurile șterse după activarea păstrării în coș. ",
+    "Could not remove trusted sender {sender}" : "Expeditorul de încredere {sender} nu poate fi șters",
+    "No senders are trusted at the moment." : "Niciun expeditor de încredere în acest moment. ",
+    "Untitled event" : "Eveniment fără titlu",
+    "(organizer)" : "(organizator)",
+    "Import into {calendar}" : "Importă în {calendar}",
+    "Event imported into {calendar}" : "Eveniment importat în {calendar}",
+    "Reservation {id}" : "Rezervare {id}",
+    "Recipient" : "Destinatar",
+    "Successfully updated config for \"{domain}\"" : "S-a actualizat configurația pentru \"{domain}\"",
+    "Error saving config" : "Eroare la salvarea configurației",
+    "Saved config for \"{domain}\"" : "A fost salvată configurația pentru \"{domain}\"",
+    "Mail app" : "Aplicația Mail",
+    "The mail app allows users to read mails on their IMAP accounts." : "Aplicația de mail permite utilizatorilor să citească mailurile din conturile lor IMAP.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Aici găsiți setările generale pentru instanță. Setările specifice pentru utilizator se găsesc în aplicație (în colțul din stânga, jos).",
+    "Account provisioning" : "Alimentare cont",
+    "Add new config" : "Adaugă o nouă configurație",
+    "Allow additional mail accounts" : "Permite conturi de mail suplimentare",
+    "Allow additional Mail accounts from User Settings" : "Permite conturi de mail suplimentare în setările utilizator",
+    "Anti Spam Service" : "Serviciul anti-spam",
+    "The original message will be attached as a \"message/rfc822\" attachment." : "Mesajul original va fi atașat ca atașament \"message/rfc822\".",
+    "\"Mark as Spam\" Email Address" : "\"Marchează ca Spam\" adresa de Email",
+    "\"Mark Not Junk\" Email Address" : "\"Marchează ca Not Junk\" adresa de Email ",
+    "Reset" : "Resetare",
+    "Client ID" : "ID client",
+    "Client secret" : "Secret client",
+    "Unlink" : "Deconectare",
+    "User" : "Utilizator",
+    "Host" : "Gazdă",
+    "Port" : "Portul",
+    "Use master password" : "Folosește master password",
+    "LDAP aliases integration" : "Integrare aliasuri LDAP",
+    "Enable LDAP aliases integration" : "Activează integrarea aliasurilor LDAP",
+    "Save Config" : "Salvează configurația",
+    "S/MIME certificates" : "Certificatele S/MIME",
+    "Certificate name" : "Nume certificat",
+    "E-mail address" : "Adresa de E-mail ",
+    "Valid until" : "Valabil până la",
+    "Delete certificate" : "Șterge certificatul",
+    "Certificate" : "Certificat",
+    "Submit" : "Trimite",
+    "Account connected" : "Cont conectat",
+    "You can close this window" : "Puteți închide fereastra",
+    "Connect your mail account" : "Conectați-vă contul de mail",
+    "To add a mail account, please contact your administrator." : "Pentru adăugarea unui cont de mail, contactați administratorul.",
     "All" : "Toate ",
     "Drafts" : "Schițe",
     "Favorites" : "Favorite",
@@ -448,6 +523,8 @@ OC.L10N.register(
     "Redirect" : "Deviere",
     "The link leads to %s" : "Link-ul duce la %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Dacă nu doriți să vizitați acea pagină, vă puteți întoarce la <a href=\"%s\">Mail</a>.",
-    "Continue to %s" : "Continuă către %s"
+    "Continue to %s" : "Continuă către %s",
+    "Draft: " : "Schiță:",
+    "Actions" : "Acțiuni"
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
