@@ -12,6 +12,7 @@ OC.L10N.register(
     "Signature" : "අත්සන",
     "Go back" : "ආපසු යන්න",
     "Cancel" : "අවලංගු කරන්න",
+    "Accounts" : "Accounts",
     "General" : "සමාන්‍යය",
     "About" : "පිළිබඳ",
     "Archive" : "සංරක්ෂණය",
@@ -42,7 +43,11 @@ OC.L10N.register(
     "Close" : "වසන්න",
     "Body" : "අන්තර්ගතය",
     "Date" : "දිනය",
+    "User" : "පරිශීලක",
+    "Host" : " ධාරකය",
+    "Certificate" : "සහතිකය",
     "All" : "සියල්ල",
-    "Favorites" : "ප්‍රියතම"
+    "Favorites" : "ප්‍රියතම",
+    "Actions" : "ක්‍රියාමාර්ග"
 },
 "nplurals=2; plural=(n != 1);");
