@@ -188,7 +188,6 @@ OC.L10N.register(
     "No trash mailbox configured" : "Ni nastavljenega poštne mape za smeti",
     "Could not delete message" : "Sporočila ni mogoče izbrisati",
     "Could not archive message" : "Ni mogoče arhivirati sporočila",
-    "Draft: " : "Osnutek:",
     "Encrypted message" : "Šifrirano sporočilo",
     "This message is unread" : "To sporočilo še ni bilo prebrano",
     "Unfavorite" : "Odstrani oznako priljubljeno",
@@ -385,6 +384,7 @@ OC.L10N.register(
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Nastavljen podpis je večji od 2 MB. Velikost lahko vpliva na delovanje urejevalnika.",
     "Save signature" : "Shrani podpis",
     "Place signature above quoted text" : "Postavi podpis nad navedeno besedilo.",
+    "Message source" : "Vir sporočila",
     "An error occurred, unable to rename the tag." : "Prišlo je do napake, oznake ni mogoče preimenovati.",
     "Saving new tag name …" : "Poteka shranjevanje imena oznake ...",
     "Delete tag" : "Izbriši oznako",
@@ -393,6 +393,122 @@ OC.L10N.register(
     "Tag name is a hidden system tag" : "Ime oznake je skrita sistemska oznaka",
     "Tag already exists" : "Oznaka že obstaja",
     "An error occurred, unable to create the tag." : "Prišlo je do napake, oznake ni mogoče ustvariti.",
+    "Add default tags" : "Dodaj privzete oznake",
+    "Add tag" : "Dodaj oznako",
+    "Saving tag …" : "Poteka shranjevanje ozake ...",
+    "Task created" : "Naloga je ustvarjena",
+    "Could not create task" : "Naloge ni mogoče ustvariti",
+    "No calendars with task list support" : "Koledar s podporo seznama nalog",
+    "Could not load your message thread" : "Ni mogoče naložiti niti sporočil",
+    "The thread doesn't exist or has been deleted" : "Nit ne obstaja ali pa je bila izbrisana",
+    "Loading thread" : "Poteka nalaganje niti",
+    "Not found" : "Predmeta ni mogoče najti",
+    "Encrypted & verified " : "Šifrirano in overjeno",
+    "Signature verified" : "Podpis je overjen",
+    "Signature unverified " : "Podpis ni overjen",
+    "Reply all" : "Odgovori vsem",
+    "Unsubscribe" : "Prekliči naročnino",
+    "Reply to sender only" : "Odgovori le pošiljatelju",
+    "Mark as unfavorite" : "Odstrani oznako priljubljeno",
+    "Mark as favorite" : "Označi kot priljubljeno",
+    "Mark as unread" : "Označi kot neprebrano",
+    "Mark as read" : "Označi kot prebrano",
+    "The message could not be translated" : "Sporočila ni mogoče prevesti",
+    "Translation copied to clipboard" : "Prevod je kopiran v odložišče",
+    "Translation could not be copied" : "Prevoda ni mogoče kopirati!",
+    "Translate message" : "Prevedi sporočilo",
+    "Source language to translate from" : "Izvorni jezik za prevod",
+    "Translate from" : "Prevedi iz",
+    "Target language to translate into" : "Ciljni jezik za prevod",
+    "Translate to" : "Prevedi v",
+    "Translating" : "Poteka prevajanje",
+    "Copy translated text" : "Kopiraj prevedeno besedilo",
+    "Could not remove trusted sender {sender}" : "Ni mogoče odstraniti zanesljivega pošiljatelja {sender}",
+    "No senders are trusted at the moment." : "Ni še zavedenih zaupanja vrednih pošiljateljev.",
+    "Untitled event" : "Neimenovan dogodek",
+    "(organizer)" : " (skliče dogodek)",
+    "Import into {calendar}" : "Uvozi v koledar {calendar}",
+    "Event imported into {calendar}" : "Dogodek je uvožen v koledar {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Let {flightNr} iz {depAirport} na letališče {arrAirport}",
+    "Airplane" : "Letalo",
+    "Reservation {id}" : "Rezervacija {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} iz {depStation} v {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Vlak iz {depStation} v {arrStation}",
+    "Train" : "Vlak",
+    "Flag" : "Zastavica",
+    "Recipient" : "Prejemnik",
+    "Delete filter" : "Izbriši filter",
+    "Operator" : "Operator",
+    "contains" : "vsebuje",
+    "matches" : "se sklada z",
+    "Priority" : "Prednost",
+    "Successfully updated config for \"{domain}\"" : "Nastavitve za domeno »{domain}« so uspešno posodobljene.",
+    "Error saving config" : "Napaka shranjevanja nastavitev",
+    "Saved config for \"{domain}\"" : "Nastavitve za domeno »{domain}« so shranjene.",
+    "Could not save provisioning setting" : "Ni mogoče shraniti nastavitev povezovanja",
+    "_Successfully provisioned {count} account._::_Successfully provisioned {count} accounts._" : ["Uspešno je zaključeno povezovanje {count} računa.","Uspešno je zaključeno povezovanje {count} računov.","Uspešno je zaključeno povezovanje {count} računov.","Uspešno je zaključeno povezovanje {count} računov."],
+    "There was an error when provisioning accounts." : "Prišlo je do napake med povezovanjem računov.",
+    "Successfully deleted and deprovisioned accounts for \"{domain}\"" : "Brisanje in odstranjevanje povezovanja računov za »{domain}« je uspešno končano.",
+    "Error when deleting and deprovisioning accounts for \"{domain}\"" : "Napaka pri brisanju in odstranjevanju povezovanja računov za »{domain}«",
+    "Mail app" : "Program Pošta",
+    "The mail app allows users to read mails on their IMAP accounts." : "Program Mail omogoča uporabnikom branje sporočil z računov IMAP.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Na tem mestu so zbrane nastavitve celotnega okolja. Uporabniške nastavitve so v posameznem programu (spodnji levi kot).",
+    "Account provisioning" : "Povezovanje računov",
+    "A provisioning configuration will provision all accounts with a matching email address." : "Nastavitve povezovanja zagotavljajo povezovanje vseh računov s skladnim elektronskim naslovom.",
+    "Using the wildcard (*) in the provisioning domain field will create a configuration that applies to all users, provided they do not match another configuration." : "Uporaba nadomestnih znakov (*) v polju priprave domene ustvari nastavitev, ki je nato uveljavljena za vse uporabnike, če za posemeznike niso v veljavi druge nastavitve.",
+    "The provisioning mechanism will prioritise specific domain configurations over the wildcard domain configuration." : "Mehanizem za povezovanje prednostno privzame nastavitve domen pred nastavitvami z uporabo nadomestnih znakov.",
+    "Should a new matching configuration be found after the user was already provisioned with another configuration, the new configuration will take precedence and the user will be reprovisioned with the configuration." : "Če bo ustvarjena nova nastavitev po tem, ko je bil uporabnik že povezan, bo imela prednostno uporabljena novejša nastavitev, uporabnik pa bo ponovno povezan v nov sistem.",
+    "If you only want to provision one domain for all users, use the wildcard (*)." : "Če želite ponuditi eno domeno vsem uporabnikom, to zapišite z nadomestnimi znaki (*).",
+    "This setting only makes most sense if you use the same user back-end for your Nextcloud and mail server of your organization." : "Nastavitev je smiselna le, če v ustanovi uporabljate isto uporabniško zaledje za Nextcloud in poštni strežnik.",
+    "Provisioning Configurations" : "Nastavitve povezovanja računov",
+    "Add new config" : "Dodaj nove nastavitve",
+    "Provision all accounts" : "Zagotovi povezanost vseh računov",
+    "Anti Spam Service" : "Storitve proti neželeni pošti",
+    "You can set up an anti spam service email address here." : "Določiti je mogoče elektronski naslov za storitve neželenih sporočil.",
+    "Gmail integration" : "Združevalnik Gmail",
+    "Anti Spam" : "Anti Spam",
+    "\"Mark as Spam\" Email Address" : "Označi sporočila z elektronskega naslova kot »Neželena sporočila«",
+    "\"Mark Not Junk\" Email Address" : "Označi sporočila z elektronskega naslova kot »Niso neželena sporočila«",
+    "Reset" : "Ponastavi",
+    "Client ID" : "ID Odjemalca",
+    "Client secret" : "Skrivni ključ odjemalca",
+    "Unlink" : "Odstrani povezavo",
+    "Domain Match: {provisioningDomain}" : "Skladna domena: {provisioningDomain}",
+    "Email: {email}" : "Elektronski naslov: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} na {host}:{port} ({ssl} encryption)",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} na {host}:{port} ({ssl} encryption)",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} na {host}:{port} (šifriranje {ssl})",
+    "Configuration for \"{provisioningDomain}\"" : "Nastavitve za »{provisioningDomain}«",
+    "Provisioning domain" : "Domena za povezovanje",
+    "Email address template" : "Predloga elektronskega naslova",
+    "IMAP" : "IMAP",
+    "User" : "Uporabnik",
+    "Host" : "Gostitelj",
+    "Port" : "Vrata",
+    "SMTP" : "SMTP",
+    "Sieve" : "Sieve",
+    "Enable sieve integration" : "Omogoči združevalnik sieve",
+    "The LDAP aliases integration reads an attribute from the configured LDAP directory to provision email aliases." : "PRogram LDAP pridobi podatke atributa, nastavljenega v imeniku LDAP za povezovanje elektronskih naslovov z vzdevki.",
+    "A multi value attribute to provision email aliases. For each value an alias is created. Aliases existing in Nextcloud which are not in the LDAP directory are deleted." : "Nastavitev določa atribut z več vrednostmi za povezovanje vzdevkov elektronskih naslovov. Za vsako vrednost je ustvarjen vzdevek, tisti vzdevki, ki so vpisani v oblaku Nextcloud, a niso tudi v imeniku LDAP, se izbrišejo.",
+    "Save Config" : "Shrani nastavitve",
+    "Unprovision & Delete Config" : "Odstrani povezavo in izbriši nastavitve",
+    "With the settings above, the app will create account settings in the following way:" : "Z zgornjo nastavitvijo bo ustvarjen račun s podatki:",
+    "Failed to import the certificate" : "Uvažanje potrdila je spodletelo",
+    "S/MIME certificates" : "Potrdila S/MIME",
+    "Certificate name" : "Ime potrdila",
+    "E-mail address" : "Naslov elektronske pošte",
+    "Valid until" : "Veljavno do",
+    "Delete certificate" : "Izbriši potrdilo",
+    "No certificate imported yet" : "Ni še uvoženih potrdil",
+    "Import certificate" : "Uvozi potrdilo",
+    "Import S/MIME certificate" : "Uvozi potrdila S/MIME",
+    "PKCS #12 Certificate" : "Potrdilo PKCS #12",
+    "PEM Certificate" : "Potrdilo PEM",
+    "Certificate" : "Potrdilo",
+    "Private key (optional)" : "Zasebni ključ (izbirno)",
+    "Submit" : "Pošlji",
+    "Account connected" : "Račun je povezan",
+    "Connect your mail account" : "Povežite svoj elektronski račun",
     "All" : "Vse",
     "Drafts" : "Osnutki",
     "Favorites" : "Priljubljene",
@@ -423,6 +539,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Če vas sistem v nekaj sekundah ne preusmeri samodejno, pritisnite na to mesto.",
     "Redirect" : "Preusmeri",
     "The link leads to %s" : "Povezava vodi do %s",
-    "Continue to %s" : "Nadaljuj na %s"
+    "Continue to %s" : "Nadaljuj na %s",
+    "Draft: " : "Osnutek:",
+    "Actions" : "Dejanja"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
