@@ -96,6 +96,22 @@ OC.L10N.register(
     "Custom" : "E përshtatur",
     "Delete tag" : "Fshi etiketën",
     "Tag already exists" : "Etiketa ekziston",
+    "Add tag" : "Shto etiketim",
+    "Mark as unread" : "Shënoje si të palexuar",
+    "Mark as read" : "Shënoje si të lexuar",
+    "Recipient" : "Marrës",
+    "matches" : "përputhje",
+    "Priority" : "Përparësi",
+    "Reset" : "Rivendos",
+    "Client ID" : "ID klienti",
+    "Client secret" : "E fshehtë klienti",
+    "User" : "Përdorues",
+    "Host" : "Strehë",
+    "Port" : "Porta",
+    "Valid until" : "E vlefshme deri më",
+    "Certificate" : "Çertifikata",
+    "Submit" : "Dërgo",
+    "Connect your mail account" : "Lidhni llogarinë tuaj të postës elektronike",
     "All" : "Të gjithë",
     "Drafts" : "Skica",
     "Favorites" : "Favorites",
@@ -113,6 +129,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klikoni këtu nëse nuk ridrejtoheni automatikisht brenda disa sekondave",
     "Redirect" : "Ridrejtoje",
     "The link leads to %s" : "Lidhja shpie te %s",
-    "Continue to %s" : "Vazhdo te %s"
+    "Continue to %s" : "Vazhdo te %s",
+    "Actions" : "Veprimet"
 },
 "nplurals=2; plural=(n != 1);");
