@@ -42,6 +42,8 @@ OC.L10N.register(
     "Body" : "Telo",
     "Date" : "Date",
     "Tags" : "Oznake",
+    "Not found" : "Nije nađeno",
+    "User" : "Korisnik",
     "All" : "Sve",
     "Favorites" : "Omiljene",
     "Continue to %s" : "Nastavi na %s"
