@@ -144,7 +144,6 @@ OC.L10N.register(
     "No trash mailbox configured" : "Ingen skräpkorg är konfigurerad",
     "Could not delete message" : "Kunde inte radera meddelande",
     "Could not archive message" : "Kunde inte arkivera meddelandet",
-    "Draft: " : "Utkast:",
     "Unfavorite" : "Inte favorit",
     "Favorite" : "Favorit",
     "Unread" : "Oläst",
@@ -284,10 +283,74 @@ OC.L10N.register(
     "Signature …" : "Signatur …",
     "Save signature" : "Spara signatur",
     "Place signature above quoted text" : "Placera signaturen ovanför citerad text",
+    "Message source" : "Meddelandekälla",
     "An error occurred, unable to rename the tag." : "Ett fel uppstod, kunde inte byta taggens namn.",
     "Delete tag" : "Radera tagg",
     "Tag already exists" : "Taggen finns redan",
     "An error occurred, unable to create the tag." : "Ett fel uppstod, kunde inte spara taggen.",
+    "Add default tags" : "Lägg till standardtaggar",
+    "Add tag" : "Lägg till tagg",
+    "Saving tag …" : "Sparar tagg …",
+    "Could not load your message thread" : "Det gick inte att ladda meddelandetråden",
+    "Not found" : "Hittades inte",
+    "Reply all" : "Svara alla",
+    "Unsubscribe" : "Avsluta prenumeration",
+    "Reply to sender only" : "Svara endast avsändaren",
+    "Mark as unread" : "Markera som oläst",
+    "Mark as read" : "Markera som läst",
+    "The message could not be translated" : "Meddelandet kunde inte översättas",
+    "Translation copied to clipboard" : "Översättningen har kopierats till urklipp",
+    "Translation could not be copied" : "Översättningen kunde inte kopieras",
+    "Translate message" : "Översätt meddelande",
+    "Source language to translate from" : "Språk att översätta från",
+    "Translate from" : "Översätt från",
+    "Target language to translate into" : "Språk att översätta till",
+    "Translate to" : "Översätt till",
+    "Translating" : "Översätter",
+    "Copy translated text" : "Kopiera översatt text",
+    "No senders are trusted at the moment." : "Inga avsändare är betrodda för tillfället.",
+    "Untitled event" : "Namnlös händelse",
+    "(organizer)" : "(arrangör)",
+    "Import into {calendar}" : "Importera till {calendar}",
+    "Event imported into {calendar}" : "Händelse importerad till {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Flyg {flightNr} från {depAirport} till {arrAirport}",
+    "Airplane" : "Flygplan",
+    "Reservation {id}" : "Bokning {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} från {depStation} till {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Tåg från {depStation} till {arrStation}",
+    "Train" : "Tåg",
+    "Flag" : "Flag",
+    "Recipient" : "Mottagare",
+    "Delete filter" : "Ta bort filter",
+    "Operator" : "Operatör",
+    "contains" : "innehåller",
+    "matches" : "träffar",
+    "Filter name" : "Filternamn",
+    "Priority" : "Prioritet",
+    "Mail app" : "Mail-app",
+    "The mail app allows users to read mails on their IMAP accounts." : "Mail-appen tillåter användare att läsa e-post på sina IMAP-konton.",
+    "Reset" : "Återställ",
+    "Client ID" : "Klient-ID",
+    "Client secret" : "Klienthemlighet",
+    "Unlink" : "Unlink",
+    "Email: {email}" : "E-post: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} på {host}:{port} ({ssl}-krypterat)",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} på {host}:{port} ({ssl}-krypterat)",
+    "IMAP" : "IMAP",
+    "User" : "Användare",
+    "Host" : "Server",
+    "Port" : "Port",
+    "SMTP" : "SMTP",
+    "Save Config" : "Spara inställningar",
+    "* %USERID% and %EMAIL% will be replaced with the user's UID and email" : "* %USERID% och %EMAIL% kommer ersättas av användarens UID och e-post",
+    "With the settings above, the app will create account settings in the following way:" : "Med inställningarna ovan skapar appen kontoinställningar på följande sätt:",
+    "E-mail address" : "E-postadress",
+    "Valid until" : "Giltigt till",
+    "Delete certificate" : "Ta bort certifikat",
+    "Certificate" : "Certifikat",
+    "Submit" : "Skicka",
+    "Account connected" : "Konto anslutet",
+    "Connect your mail account" : "Anslut ditt e-postkonto",
     "All" : "Alla",
     "Drafts" : "Utkast",
     "Favorites" : "Favoriter",
@@ -314,6 +377,9 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Klicka här om du inte blir omdirigerad inom några sekunder.",
     "Redirect" : "Omdirigera",
     "The link leads to %s" : "Länken pekar mot %s",
-    "Continue to %s" : "Fortsätt till %s"
+    "Continue to %s" : "Fortsätt till %s",
+    "Draft: " : "Utkast:",
+    "Actions" : "Funktioner",
+    "New action" : "Ny åtgärd"
 },
 "nplurals=2; plural=(n != 1);");
