@@ -101,7 +101,6 @@ OC.L10N.register(
     "Next week – {timeLocale}" : "Tuần sau - {timeLocale}",
     "No trash mailbox configured" : "Không có hộp thư thùng rác nào được định cấu hình",
     "Could not delete message" : "Không thể xóa tin nhắn",
-    "Draft: " : "Bản nháp: ",
     "Favorite" : "Ưa thích",
     "Read" : "Đọc",
     "Mark not spam" : "Đánh dấu không phải là thư rác",
@@ -221,7 +220,50 @@ OC.L10N.register(
     "Save sieve script" : "Lưu sieve script",
     "Signature …" : "Chữ ký …",
     "Save signature" : "Lưu chữ ký",
+    "Message source" : "Nguồn tin nhắn",
     "Tag already exists" : "Thẻ đã tồn tại",
+    "Add tag" : "Thêm nhãn",
+    "Could not load your message thread" : "Không thể tải chuỗi tin nhắn của bạn",
+    "Not found" : "Không tìm thấy",
+    "Reply to sender only" : "Chỉ trả lời người gửi",
+    "Mark as unread" : "Đánh dấu là chưa đọc",
+    "Mark as read" : "Đánh dấu đã đọc",
+    "Could not remove trusted sender {sender}" : "Không thể xóa người gửi đáng tin cậy {sender}",
+    "No senders are trusted at the moment." : "Không có người gửi nào được tin cậy vào lúc này.",
+    "Untitled event" : "Sự kiện không tiêu đề",
+    "(organizer)" : "(organizer)",
+    "Import into {calendar}" : "Nhập vào {calendar}",
+    "Event imported into {calendar}" : "Sự kiện được nhập vào {calendar}",
+    "Flight {flightNr} from {depAirport} to {arrAirport}" : "Chuyến bay {flightNr} từ {depAirport} đến {arrAirport}",
+    "Airplane" : "Máy bay",
+    "Reservation {id}" : "Dự phòng {id}",
+    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} từ {depStation} đến {arrStation}",
+    "Train from {depStation} to {arrStation}" : "Đi tàu từ {depStation} đến {arrStation}",
+    "Train" : "Tàu hỏa",
+    "Recipient" : "Người nhận",
+    "Delete filter" : "Xóa bộ lọc ",
+    "contains" : "chứa",
+    "matches" : "so sánh",
+    "Mail app" : "Ứng dụng thư",
+    "The mail app allows users to read mails on their IMAP accounts." : "Ứng dụng thư cho phép người dùng đọc thư trên tài khoản IMAP của họ.",
+    "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Tại đây bạn có thể tìm thấy các cài đặt cho toàn phiên bản. Cài đặt người dùng cụ thể được tìm thấy trong chính ứng dụng (góc dưới bên trái).",
+    "Reset" : "Đặt lại",
+    "Client ID" : "ID khách hàng",
+    "Email: {email}" : "Thư điện tử: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} trên {host}: {port} (mã hóa {ssl})",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} trên {host}: {port} (mã hóa {ssl})",
+    "Sieve: {user} on {host}:{port} ({ssl} encryption)" : "Sieve: {user} trên {host}: {port} (mã hóa {ssl})",
+    "User" : "Người dùng",
+    "Host" : "Máy chủ",
+    "Port" : "Cổng",
+    "Enable sieve integration" : "Bật tích hợp sieve",
+    "With the settings above, the app will create account settings in the following way:" : "Với cài đặt ở trên, ứng dụng sẽ tạo cài đặt tài khoản theo cách sau:",
+    "E-mail address" : "Địa chỉ email",
+    "Valid until" : "Có hiệu lực đến",
+    "Certificate" : "Chứng chỉ",
+    "Submit" : "Gửi",
+    "Account connected" : "Tài khoản đã được kết nối",
+    "Connect your mail account" : "Kết nối tài khoản thư của bạn",
     "All" : "Tất cả",
     "Drafts" : "Bản nháp",
     "Favorites" : "Ưa thích",
@@ -246,6 +288,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Nhấp vào đây nếu bạn không được chuyển hướng tự động trong vòng vài giây tới",
     "Redirect" : "Chuyển hướng",
     "The link leads to %s" : "Liên kết dẫn đến %s",
-    "Continue to %s" : "Tiếp tục %s"
+    "Continue to %s" : "Tiếp tục %s",
+    "Draft: " : "Bản nháp: ",
+    "Actions" : "Hành động"
 },
 "nplurals=1; plural=0;");
