@@ -127,9 +127,10 @@ class ContactsIntegration {
 				$receivers[] = [
 					'id' => $id,
 					// Show full name if possible or fall back to email
-					'label' => (empty($fn) ? $e : "$fn ($e)"),
+					'label' => $fn,
 					'email' => $e,
 					'photo' => $photo,
+					'source' => 'contacts',
 				];
 			}
 		}
@@ -231,7 +232,7 @@ class ContactsIntegration {
 	/**
 	 * @param string[] $fields
 	 */
-	private function doSearch(string $term, array $fields, bool $strictSearch, bool $forceSAB = false) : array {
+	private function doSearch(string $term, array $fields, bool $strictSearch) : array {
 		$allowSystemUsers = $this->config->getAppValue('core', 'shareapi_allow_share_dialog_user_enumeration', 'no') === 'yes';
 
 		$result = $this->contactsManager->search($term, $fields, [
@@ -240,7 +241,7 @@ class ContactsIntegration {
 		]);
 		$matches = [];
 		foreach ($result as $r) {
-			if ((!$allowSystemUsers && !$forceSAB) && isset($r['isLocalSystemBook']) && $r['isLocalSystemBook']) {
+			if (!$allowSystemUsers && isset($r['isLocalSystemBook']) && $r['isLocalSystemBook']) {
 				continue;
 			}
 			$id = $r['UID'];
@@ -268,7 +269,7 @@ class ContactsIntegration {
 	/**
 	 * Extracts all Contacts with the specified name
 	 */
-	public function getContactsWithName(string $name, bool $forceSAB = false): array {
-		return $this->doSearch($name, ['FN'], false, $forceSAB);
+	public function getContactsWithName(string $name): array {
+		return $this->doSearch($name, ['FN'], false);
 	}
 }
